/**
 * SheetManager
 * Controls all widget "sheets", this includes all the popups for recordings etc
 *
 */
function SheetManager(){
	var _self = this;
	
	this.active = false;
	this.epgSheetActive = false;
	this.updateSheetActive = false;
	this.extraDaysSheetActive = false;
	this.authWelcomeSheetActive = false;
	
	this.height = 0;
	
	this.seriesDeviceMenu = new Array();
	this.seriesTypeMenu = new Array();
	this.seriesChannelMenu = new Array();
	this.seriesTimeMenu = new Array();
	
	this.seriesDeviceControllers = new Array();
	
	this.seriesDeviceIndex = 0;
	this.seriesTypeIndex = 0;
	this.seriesNetworkIndex = 1; // Make 'This Network' the default. ( 0: Any, 1: This)
	this.seriesTimeIndex = 0;
	this.seriesQualityIndex = 0;
	this.seriesLimitIndex = 0;

	this.keywordDeviceIndex = 0;
	this.keywordTypeIndex = 0;
	this.keywordNetworkIndex = 1; // Make 'This Network' the default. ( 0: Any, 1: This)
	this.keywordQualityIndex = 0;
	this.keywordLimitIndex = 0;
	
	this.showID = -1;
	this.seriesID = -1;
	this.seriesRecordID = -1;
	
	this.seriesInfo = {};
	
	this.titleUnderlines = new Array();
	
	this.animator = new AnimationController();
}

SheetManager.prototype.setup = function() {
	var _self = this;

	document.getElementById("epg_sheet_close").onclick = function(){ _self.closeSheet(0); };
	
	document.getElementById("sheet_button_addfav"                        ).setAttribute("onclick", "sht.doAddFav()");
	document.getElementById("sheet_button_deletefav"                     ).setAttribute("onclick", "sht.doRemoveFav()");
	document.getElementById("sheet_button_recordonce"                    ).setAttribute("onclick", "sht.showRecordOnceOptions()");
	document.getElementById("sheet_button_recordseries"                  ).setAttribute("onclick", "sht.showRecordSeriesOptions()");
	document.getElementById("sheet_button_updateseries"                  ).setAttribute("onclick", "sht.showUpdateSeriesOptions()");
	document.getElementById("sheet_button_recordkeyword"                 ).setAttribute("onclick", "sht.showRecordKeywordOptions()");
	document.getElementById("sheet_button_updatekeyword"                 ).setAttribute("onclick", "sht.showUpdateKeywordOptions()");
	document.getElementById("sheet_button_createkeyword"                 ).setAttribute("onclick", "sht.showCreateKeywordOptions()");
	document.getElementById("sheet_button_deletekeyword"                 ).setAttribute("onclick", "sht.doRemoveKeyword()");
	document.getElementById("epg_sheet_single_record_cancel"             ).setAttribute("onclick", "sht.showControls()");
	document.getElementById("epg_sheet_series_record_cancel"             ).setAttribute("onclick", "sht.showControls()");

	document.getElementById("sheet-record-series-button-record"          ).setAttribute("onclick", "sht.doSeriesRecord()");
	document.getElementById("sheet-update-series-button-update"          ).setAttribute("onclick", "sht.doSeriesRecordUpdate()");

	document.getElementById("epg_sheet_keyword_record_cancel"            ).setAttribute("onclick", "sht.showControls()");
	document.getElementById("sheet-record-keyword-button-update"         ).setAttribute("onclick", "sht.doKeywordRecordUpdate()");
	document.getElementById("sheet-record-keyword-button-create"         ).setAttribute("onclick", "sht.doKeywordRecordUpdate()");
	
	document.getElementById("epg-sheet-series-record-devices"            ).setAttribute("onchange", "sht.changeSeriesRecordDeviceFromMenu()");
	document.getElementById("epg-sheet-single-record-devices"            ).setAttribute("onchange", "sht.changeSingleRecordDeviceFromMenu()");
	document.getElementById("epg-sheet-series-record-type-menu"          ).setAttribute("onchange", "sht.changeSeriesRecordTypeFromMenu()");
	document.getElementById("epg-sheet-series-record-time-menu"          ).setAttribute("onchange", "sht.changeSeriesRecordTimeFromMenu()");
	document.getElementById("epg-sheet-series-record-networks"           ).setAttribute("onchange", "sht.changeSeriesRecordNetworkFromMenu()");
	document.getElementById("epg-sheet-series-record-quality-menu"       ).setAttribute("onchange", "sht.changeSeriesRecordQualityFromMenu()");
	document.getElementById("epg-sheet-series-record-limit-menu"         ).setAttribute("onchange", "sht.changeSeriesRecordLimitFromMenu()");

	document.getElementById("epg-sheet-keyword-record-pattern"           ).setAttribute("onchange", "sht.changeKeywordRecordPattern()");
	document.getElementById("epg-sheet-keyword-record-action-menu"       ).setAttribute("onchange", "sht.changeKeywordRecordActionFromMenu()");
	document.getElementById("epg-sheet-keyword-record-devices"           ).setAttribute("onchange", "sht.changeKeywordRecordDeviceFromMenu()");
	document.getElementById("epg-sheet-keyword-record-type-menu"         ).setAttribute("onchange", "sht.changeKeywordRecordTypeFromMenu()");
	document.getElementById("epg-sheet-keyword-record-networks"          ).setAttribute("onchange", "sht.changeKeywordRecordNetworkFromMenu()");
	document.getElementById("epg-sheet-keyword-record-quality-menu"      ).setAttribute("onchange", "sht.changeKeywordRecordQualityFromMenu()");
	document.getElementById("epg-sheet-keyword-record-limit-menu"        ).setAttribute("onchange", "sht.changeKeywordRecordLimitFromMenu()");

    this.populateTimeListSeries();
}

SheetManager.prototype.changeSingleRecordDeviceFromMenu = function(index) {
	this.changeSeriesRecordDevice(document.getElementById("epg-sheet-single-record-devices").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordDeviceFromMenu = function(index) {
	this.changeSeriesRecordDevice(document.getElementById("epg-sheet-series-record-devices").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordTypeFromMenu = function(index) {
	this.changeSeriesRecordType(document.getElementById("epg-sheet-series-record-type-menu").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordTimeFromMenu = function(index) {
	this.changeSeriesRecordTime(document.getElementById("epg-sheet-series-record-time-menu").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordNetworkFromMenu = function(index) {
	this.changeSeriesRecordNetwork(document.getElementById("epg-sheet-series-record-networks").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordQualityFromMenu = function(index) {
	this.changeSeriesRecordQuality(document.getElementById("epg-sheet-series-record-quality-menu").selectedIndex);
}

SheetManager.prototype.changeSeriesRecordLimitFromMenu = function(index) {
	this.changeSeriesRecordLimit(document.getElementById("epg-sheet-series-record-limit-menu").selectedIndex);
}


SheetManager.prototype.changeKeywordRecordActionFromMenu = function(index) {
	this.changeKeywordRecordAction(document.getElementById("epg-sheet-keyword-record-action-menu").selectedIndex);
}

SheetManager.prototype.changeKeywordRecordDeviceFromMenu = function(index) {
	this.changeKeywordRecordDevice(document.getElementById("epg-sheet-keyword-record-devices").selectedIndex);
}

SheetManager.prototype.changeKeywordRecordTypeFromMenu = function(index) {
	this.changeKeywordRecordType(document.getElementById("epg-sheet-keyword-record-type-menu").selectedIndex);
}

SheetManager.prototype.changeKeywordRecordNetworkFromMenu = function(index) {
	this.changeKeywordRecordNetwork(document.getElementById("epg-sheet-keyword-record-networks").selectedIndex);
}

SheetManager.prototype.changeKeywordRecordQualityFromMenu = function(index) {
	this.changeKeywordRecordQuality(document.getElementById("epg-sheet-keyword-record-quality-menu").selectedIndex);
}

SheetManager.prototype.changeKeywordRecordLimitFromMenu = function(index) {
	this.changeKeywordRecordLimit(document.getElementById("epg-sheet-keyword-record-limit-menu").selectedIndex);
}

SheetManager.prototype.populateDeviceLists = function() {
	this.seriesDeviceMenu.length = 0;
	this.seriesDeviceControllers.length = 0;
	
	var devices = dv.deviceList;
	for(x=0;x<devices.length;x++){
		var option  = new Option(devices[x]["label"], devices[x]["id"]);
		var option2 = new Option(devices[x]["label"], devices[x]["id"]);
		var option3 = new Option(devices[x]["label"], devices[x]["id"]);
		document.getElementById("epg-sheet-single-record-devices").options[x] = option;
		document.getElementById("epg-sheet-series-record-devices").options[x] = option2;
		document.getElementById("epg-sheet-keyword-record-devices").options[x] = option3;
	}
	
	if(document.getElementById("epg-sheet-series-record-devices").options.length > 0){
		this.seriesDeviceIndex = 0;
		document.getElementById("epg-sheet-series-record-device").innerText = document.getElementById("epg-sheet-series-record-devices").options[0].text;
		document.getElementById("epg-sheet-single-record-device").innerText = document.getElementById("epg-sheet-series-record-devices").options[0].text;
	}

	if(document.getElementById("epg-sheet-keyword-record-devices").options.length > 0){
		this.keywordDeviceIndex = 0;
		document.getElementById("epg-sheet-keyword-record-device").innerText = document.getElementById("epg-sheet-keyword-record-devices").options[0].text;
	}
}

SheetManager.prototype.populateNetworkLists = function() {
	var networks = net.networkList;
	var option  = new Option("Any Network", "-1");
	document.getElementById("epg-sheet-series-record-networks").options[0] = option;

	var option2  = new Option("Any Network", "-1");
	document.getElementById("epg-sheet-keyword-record-networks").options[0] = option2;

	for(x=0;x<networks.length;x++){
		var option  = new Option(networks[x]["name"], networks[x]["id"]);
		var option2 = new Option(networks[x]["name"], networks[x]["id"]);
		document.getElementById("epg-sheet-series-record-networks").options[x+1] = option;
		document.getElementById("epg-sheet-keyword-record-networks").options[x+1] = option2;
	}
	
	if(document.getElementById("epg-sheet-series-record-networks").options.length > 0){
		this.seriesNetworkIndex = 0;
		document.getElementById("epg-sheet-series-record-network").innerText = document.getElementById("epg-sheet-series-record-networks").options[0].text;
	}

	if(document.getElementById("epg-sheet-keyword-record-networks").options.length > 0){
		this.keywordNetworkIndex = 0;
		document.getElementById("epg-sheet-keyword-record-network").innerText = document.getElementById("epg-sheet-keyword-record-networks").options[0].text;
	}
}

SheetManager.prototype.populateTimeListShow = function() {
	while(document.getElementById("epg-sheet-series-record-time-menu").hasChildNodes())
		document.getElementById("epg-sheet-series-record-time-menu").removeChild(document.getElementById("epg-sheet-series-record-time-menu").firstChild);

	var option  = new Option("Any Time", "-1");
	document.getElementById("epg-sheet-series-record-time-menu").options[0] = option;

	var option2  = new Option("This Time", "0");
	document.getElementById("epg-sheet-series-record-time-menu").options[1] = option2;

    this.seriesTimeIndex = 0;
    document.getElementById("epg-sheet-series-record-time").innerText = document.getElementById("epg-sheet-series-record-time-menu").options[0].text;
}

SheetManager.prototype.populateTimeListSeries = function() {
	while(document.getElementById("epg-sheet-series-record-time-menu").hasChildNodes())
		document.getElementById("epg-sheet-series-record-time-menu").removeChild(document.getElementById("epg-sheet-series-record-time-menu").firstChild);

	var option  = new Option("Any Time", "-1");
	document.getElementById("epg-sheet-series-record-time-menu").options[0] = option;

	var minsFromMidnight = 0;
	for(minsFromMidnight=0; minsFromMidnight<1440; minsFromMidnight += 5) {
		var hoursFromMidnight = Math.floor(minsFromMidnight / 60);
		var clockHour = hoursFromMidnight;
		if(clockHour == 0) clockHour = 12;
		else if(clockHour > 12) clockHour -= 12;
		var ampm = "am";
		if(hoursFromMidnight>12) ampm = "pm";
		var clockMinute = minsFromMidnight % 60;
		var labelString = clockHour + ":" + ((clockMinute < 10) ? "0" + clockMinute : clockMinute) + " " + ampm;

		var arrayIndex = (minsFromMidnight/5) + 1;
        var option  = new Option(labelString, minsFromMidnight);
        document.getElementById("epg-sheet-series-record-time-menu").options[arrayIndex] = option;
	}
	
    this.seriesNetworkIndex = 0;
    document.getElementById("epg-sheet-series-record-time").innerText = document.getElementById("epg-sheet-series-record-time-menu").options[0].text;
}

SheetManager.prototype.showControls = function(){
	document.getElementById("epg-sheet-buttons").style.opacity = 0
	document.getElementById("epg-sheet-buttons").style.display = "block"
	document.getElementById("epg-sheet-buttons").style.zIndex = 1;
	document.getElementById("epg-sheet-record-options").style.zIndex = 2;

	var sheetTopHeight           = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),           "").getPropertyValue("height"), 10);
	var sheetSeriesOptionsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-record-options"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight        = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),        "").getPropertyValue("height"), 10);
	var sheetButtonsHeight       = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),       "").getPropertyValue("height"), 10);
	
	var fadeOut = new AnimationObject(document.getElementById("epg-sheet-record-options"));
	fadeOut.setOptions(kAnimateOptionsHide, 20);
	fadeOut.pushPhase(kAnimateOpacity, 1, 0, 10, 10, null)

	var resize = new AnimationObject(document.getElementById("epg-sheet-record-options"));
	resize.setOptions(0, 10);
	resize.pushPhase(kAnimatorResizeHeight, parseInt(document.getElementById("epg-sheet-record-options").style.height, 10), sheetButtonsHeight, 10, 0, null)

	var move = new AnimationObject(document.getElementById("epg-sheet-bottom"));
	move.setOptions(0, 10);
	move.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet-bottom").style.top, 10), sheetTopHeight + sheetButtonsHeight, 10, 0, null)

	document.getElementById("epg-sheet-buttons").style.opacity = 1
	this.animator.purge();
	this.animator.purgeCallbacks();
	this.animator.pushGroup(Array(fadeOut, move, resize));
	this.animator.prepare(350, 20);
	this.animator.run();
}

SheetManager.prototype.showRecordOnceOptions = function(){
	document.getElementById("epg-sheet-series-record-options").style.display = "none"
	document.getElementById("epg-sheet-keyword-record-options").style.display = "none"
	document.getElementById("epg-sheet-single-record-options").style.opacity = 0
	document.getElementById("epg-sheet-single-record-options").style.display = "block"
	document.getElementById("epg-sheet-record-options").style.display = "block"
	document.getElementById("epg-sheet-record-options").style.opacity = 1;
	document.getElementById("epg-sheet-buttons").style.zIndex = 2;
	document.getElementById("epg-sheet-record-options").style.zIndex = 1;
	
	var sheetTopHeight           = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),"").getPropertyValue("height"), 10);
	var sheetSeriesOptionsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-single-record-options"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight        = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),"").getPropertyValue("height"), 10);
	var sheetButtonsHeight       = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),"").getPropertyValue("height"), 10);
	sheetSeriesOptionsHeight += 12;

	document.getElementById("epg-sheet-record-options").style.height = sheetButtonsHeight + "px"
	document.getElementById("epg-sheet-record-options").style.top = sheetTopHeight + "px"
	sheetHeight = sheetTopHeight + sheetSeriesOptionsHeight + sheetBottomHeight
	document.getElementById("epg-sheet-single-record-options").style.opacity = 1;
	
	var fadeOut = new AnimationObject(document.getElementById("epg-sheet-buttons"));
	fadeOut.setOptions(kAnimateOptionsHide, 10);
	fadeOut.pushPhase(kAnimateOpacity, 1, 0, 10, 0, null)

	var resize = new AnimationObject(document.getElementById("epg-sheet-record-options"));
	resize.setOptions(0, 10);
	resize.pushPhase(kAnimatorResizeHeight, parseInt(document.getElementById("epg-sheet-record-options").style.height, 10), sheetSeriesOptionsHeight, 10, 0, null)

	var move = new AnimationObject(document.getElementById("epg-sheet-bottom"));
	move.setOptions(0, 10);
	move.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet-bottom").style.top, 10), sheetTopHeight + sheetSeriesOptionsHeight, 10, 0, null)

	document.getElementById("sheet-container").style.height = sheetHeight + "px"
	resizeFront(sheetHeight + 72);

	this.animator.purge();
	this.animator.pushGroup(Array(fadeOut, move, resize));
	this.animator.prepare(175, 10);
	this.animator.run();
}

SheetManager.prototype.showUpdateSeriesOptions = function(){
	this.showRecordSeriesOptions();
	return;
//	document.getElementById("epg-sheet-series-record-options"   ).style.opacity = 0
//	document.getElementById("epg-sheet-series-record-options"   ).style.display = "block"
//	document.getElementById("sheet-rec-delete-buttons"          ).style.display = "none";
//	document.getElementById("sheet-rec-controls-divider"        ).style.display = "none";
//	
//	sheetHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet"),"").getPropertyValue("height"), 10);
//	document.getElementById("sheet-container").style.height = sheetHeight + "px"
//
//	resizeFront(sheetHeight + 72);
//	document.getElementById("epg-sheet-series-record-options").style.opacity = 1;
}

SheetManager.prototype.showRecordSeriesOptions = function(){
	document.getElementById("epg-sheet-single-record-options").style.display = "none"
	document.getElementById("epg-sheet-keyword-record-options").style.display = "none"

	document.getElementById("epg-sheet-series-record-options").style.opacity = 0
	document.getElementById("epg-sheet-series-record-options").style.display = "block"
	document.getElementById("epg-sheet-record-options"       ).style.display = "block"
	document.getElementById("epg-sheet-record-options"       ).style.opacity = 1;
	document.getElementById("epg-sheet-buttons"              ).style.zIndex = 2;
	document.getElementById("epg-sheet-record-options"       ).style.zIndex = 1;
	
	var sheetTopHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),"").getPropertyValue("height"), 10);
	var sheetSeriesOptionsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-series-record-options"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),"").getPropertyValue("height"), 10);
	var sheetButtonsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),"").getPropertyValue("height"), 10);
	sheetSeriesOptionsHeight += 12;

//	DEBUGLOG("          sheetTopHeight: " + sheetTopHeight);
//	DEBUGLOG("sheetSeriesOptionsHeight: " + sheetSeriesOptionsHeight);
//	DEBUGLOG("       sheetBottomHeight: " + sheetBottomHeight);
//	DEBUGLOG("      sheetButtonsHeight: " + sheetButtonsHeight);

	document.getElementById("epg-sheet-record-options").style.height = sheetButtonsHeight + "px"
	document.getElementById("epg-sheet-record-options").style.top = sheetTopHeight + "px"
	sheetHeight = sheetTopHeight + sheetSeriesOptionsHeight + sheetBottomHeight
	document.getElementById("epg-sheet-series-record-options").style.opacity = 1;
	
	
	var fadeOut = new AnimationObject(document.getElementById("epg-sheet-buttons"));
	fadeOut.setOptions(kAnimateOptionsHide, 10);
	fadeOut.pushPhase(kAnimateOpacity, 1, 0, 10, 0, null)

	var resize = new AnimationObject(document.getElementById("epg-sheet-record-options"));
	resize.setOptions(0, 10);
	resize.pushPhase(kAnimatorResizeHeight, parseInt(document.getElementById("epg-sheet-record-options").style.height, 10), sheetSeriesOptionsHeight, 10, 0, null)

	var move = new AnimationObject(document.getElementById("epg-sheet-bottom"));
	move.setOptions(0, 10);
	move.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet-bottom").style.top, 10), sheetTopHeight + sheetSeriesOptionsHeight, 10, 0, null)

	document.getElementById("sheet-container").style.height = sheetHeight + "px"
	resizeFront(sheetHeight + 72);

	this.animator.purge();
	this.animator.pushGroup(Array(fadeOut, move, resize));
	this.animator.prepare(175, 10);
	this.animator.run();
}

SheetManager.prototype.showUpdateKeywordOptions = function(){
	this.showRecordKeywordOptions();
}

SheetManager.prototype.showCreateKeywordOptions = function(){
	this.showRecordKeywordOptions();
}

SheetManager.prototype.showRecordKeywordOptions = function(){
	document.getElementById("epg-sheet-single-record-options").style.display = "none"
	document.getElementById("epg-sheet-series-record-options").style.display = "none"

	document.getElementById("epg-sheet-keyword-record-options").style.opacity = 0
	document.getElementById("epg-sheet-keyword-record-options").style.display = "block"
    
	document.getElementById("epg-sheet-record-options"       ).style.display = "block"
	document.getElementById("epg-sheet-record-options"       ).style.opacity = 1;
	document.getElementById("epg-sheet-buttons"              ).style.zIndex = 2;
	document.getElementById("epg-sheet-record-options"       ).style.zIndex = 1;
	
	var sheetTopHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),"").getPropertyValue("height"), 10);
	var sheetKeywordOptionsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-keyword-record-options"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),"").getPropertyValue("height"), 10);
	var sheetButtonsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),"").getPropertyValue("height"), 10);
	sheetKeywordOptionsHeight += 12;

	document.getElementById("epg-sheet-record-options").style.height = sheetButtonsHeight + "px"
	document.getElementById("epg-sheet-record-options").style.top = sheetTopHeight + "px"
	sheetHeight = sheetTopHeight + sheetKeywordOptionsHeight + sheetBottomHeight
	document.getElementById("epg-sheet-keyword-record-options").style.opacity = 1;
	
	var fadeOut = new AnimationObject(document.getElementById("epg-sheet-buttons"));
	fadeOut.setOptions(kAnimateOptionsHide, 10);
	fadeOut.pushPhase(kAnimateOpacity, 1, 0, 10, 0, null)

	var resize = new AnimationObject(document.getElementById("epg-sheet-record-options"));
	resize.setOptions(0, 10);
	resize.pushPhase(kAnimatorResizeHeight, parseInt(document.getElementById("epg-sheet-record-options").style.height, 10), sheetKeywordOptionsHeight, 10, 0, null)

	var move = new AnimationObject(document.getElementById("epg-sheet-bottom"));
	move.setOptions(0, 10);
	move.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet-bottom").style.top, 10), sheetTopHeight + sheetKeywordOptionsHeight, 10, 0, null)

	document.getElementById("sheet-container").style.height = sheetHeight + "px"
	resizeFront(sheetHeight + 72);

	this.animator.purge();
	this.animator.pushGroup(Array(fadeOut, move, resize));
	this.animator.prepare(175, 10);
	this.animator.run();
}

//SheetManager.prototype.showRecordSeriesOptionsFrame = function(){
//	epg_sheet_middle.height = epg_sheet_series_record_frame.height;
//	epg_sheet_series_record_frame.visible = true;
//	epg_sheet_controls.visible = false;
//	
//	epg_sheet_bottom.vOffset = epg_sheet_middle.height + epg_sheet_middle.vOffset;
//	epg_sheet.height = epg_sheet_top.height + epg_sheet_bottom.height + epg_sheet_middle.height;
//	sheet_container.height = epg_sheet_top.height + epg_sheet_bottom.height + epg_sheet_middle.height;
//
//	this.height = epg_sheet.height + 72;
//	
//	resizeFront(this.height);
//}

SheetManager.prototype.doSeriesRecordUpdate = function() {
	if(this.seriesID == -1 || this.seriesRecordID == -1)
		return;

	var deviceIndex = document.getElementById("epg-sheet-series-record-devices").options[this.seriesDeviceIndex].value
		
	// first_runs_only: 0 - No, 1 - Yes	
	var firstRunsOnly;
	if(this.seriesTypeIndex == 1)
		firstRunsOnly = "0";
	else
		firstRunsOnly = "1";
	
    // Network ID: 0 - Any, 1 - The one for this show
	var networkID;
	if(this.seriesNetworkIndex == 0)
		networkID = "-1";
    else
        networkID = net.networkList[this.seriesNetworkIndex-1]['id'];
        
	var startMinutes;
	if(this.seriesTimeIndex == 0)
		startMinutes = "-1";
	else {
        var arrayIndex = this.seriesTimeIndex;
        startMinutes = document.getElementById("epg-sheet-series-record-time-menu").options[arrayIndex].value;
	}

    var recordingsPerDay;
    if(this.seriesLimitIndex == 0)
        recordingsPerDay = 1;
    else if(this.seriesLimitIndex == 1)
        recordingsPerDay = 2;
    else if(this.seriesLimitIndex == 2)
        recordingsPerDay = 3;
    else if(this.seriesLimitIndex == 3)
        recordingsPerDay = 4;
    else if(this.seriesLimitIndex == 4)
        recordingsPerDay = 5;
    else 
        recordingsPerDay = 0;



    /**
     * If Device is changed then we need to do a delete for the old keyword_record_id and an add of the new details.
     */
    var origDeviceID = this.seriesInfo['series_device'];
    var origDeviceIndex = dv.indexForID(origDeviceID);

    /**
     * We only care about device changes for a "Record" type keyword, the device is ignored for "Favourite" keywords.
     */ 
    /**
     * Device Changed?
     */
    if(deviceIndex != origDeviceIndex) {
        // YES - Delete Old Entry
        api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'series_recording_id' + this.seriesInfo["series_recording_id"] + 'show_id' + this.showID + 'user_initiated' + 'true');
        delSeriesRecordingUrl = host_url + '?op=' + 'DeleteSeriesRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_recording_id=' + this.seriesInfo["series_recording_id"] + '&show_id=' + this.showID + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

        DEBUGLOG("SheetManager.js[465]: doSeriesRecordUpdate: delSeriesRecordingUrl=" + delSeriesRecordingUrl);

        rmtQueue.addToQueue(delSeriesRecordingUrl, function(json){ deletedSeriesRecording(json); });
        
        // Add New Entry
        api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceIndex + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + this.seriesQualityIndex + 'series_id' + this.seriesID + 'show_id' + this.showID + 'start_minutes' + startMinutes + 'user_initiated' + 'true');
        addSeriesRecordingUrl = host_url + '?op=' + 'AddSeriesRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_id=' + this.seriesID + '&show_id=' + this.showID + '&device_id=' + deviceIndex + '&start_minutes=' + startMinutes + '&network_id=' + networkID + '&first_runs_only=' + firstRunsOnly + '&recording_quality=' + this.seriesQualityIndex + '&recordings_per_day=' + recordingsPerDay + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

        DEBUGLOG("SheetManager.js[473]: doSeriesRecordUpdate: addSeriesRecordingUrl=" + addSeriesRecordingUrl);

        rmtQueue.addToQueue(addSeriesRecordingUrl, function(json){ addedSeriesRecording(json); });
    } else {
        // NO - Perform a "normal" update.
        api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceIndex + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + this.seriesQualityIndex + 'series_recording_id' + this.seriesRecordID + 'start_minutes' + startMinutes + 'user_initiated' + 'true');
        updateSeriesRecordingUrl = host_url + '?op=' + 'UpdateSeriesRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&device_id=' + deviceIndex + '&series_recording_id=' + this.seriesRecordID + '&start_minutes=' + startMinutes + '&network_id=' + networkID + '&first_runs_only=' + firstRunsOnly + '&recording_quality=' + this.seriesQualityIndex + '&recordings_per_day=' + recordingsPerDay + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

        DEBUGLOG("SheetManager.js[481]: doSeriesRecordUpdate: updateSeriesRecordingUrl=" + updateSeriesRecordingUrl);

        rmtQueue.addToQueue(updateSeriesRecordingUrl, function(json){ updatedSeriesRecording(json); });
    }

	this.closeSheet(0);
}

SheetManager.prototype.doSeriesRecord = function() {
	if(this.seriesID == -1)
		return;
		
	var deviceID = document.getElementById("epg-sheet-single-record-devices").options[this.seriesDeviceIndex].value
		
	// first_runs_only: 0 - No, 1 - Yes	
	var firstRunsOnly;
	if(this.seriesTypeIndex == 1)
		firstRunsOnly = "0";
	else
		firstRunsOnly = "1";
	
    // Network ID: 0 - Any, 1 - The one for this show
	var networkID = this.seriesInfo["network_id"];
	if(this.seriesNetworkIndex == 0)
		networkID = "-1";

	var startMinutes;
	if(this.seriesTimeIndex == 0)
		startMinutes = "-1";
	else {
        var arrayIndex = this.seriesTimeIndex;
        startMinutes = document.getElementById("epg-sheet-series-record-time-menu").options[arrayIndex].value;
	}

    var recordingsPerDay;
    if(this.seriesLimitIndex == 0)
        recordingsPerDay = 1;
    else if(this.seriesLimitIndex == 1)
        recordingsPerDay = 2;
    else if(this.seriesLimitIndex == 2)
        recordingsPerDay = 3;
    else if(this.seriesLimitIndex == 3)
        recordingsPerDay = 4;
    else if(this.seriesLimitIndex == 4)
        recordingsPerDay = 5;
    else 
        recordingsPerDay = 0;

	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceID + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + this.seriesQualityIndex + 'series_id' + this.seriesID + 'show_id' + this.showID + 'start_minutes' + startMinutes + 'user_initiated' + 'true');
	addSeriesRecordingUrl = host_url + '?op=' + 'AddSeriesRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_id=' + this.seriesID + '&show_id=' + this.showID + '&device_id=' + deviceID + '&start_minutes=' + startMinutes + '&network_id=' + networkID + '&first_runs_only=' + firstRunsOnly + '&recording_quality=' + this.seriesQualityIndex + '&recordings_per_day=' + recordingsPerDay + '&user_initiated=' + 'true' + '&api_check=' + api_check; 
    DEBUGLOG("SheetManager.js[535]: doSeriesRecord: addSeriesRecordingUrl=" + addSeriesRecordingUrl);
	rmtQueue.addToQueue(addSeriesRecordingUrl, function(json){ addedSeriesRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doSingleShowRecord = function() {
	if(this.showID == -1)
		return;

	var deviceID = document.getElementById("epg-sheet-single-record-devices").options[this.seriesDeviceIndex].value

	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceID + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	addSingleRecordingUrl = host_url + '?op=' + 'AddSingleRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + deviceID + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[555]: doSingleShowRecord: addSingleRecordingUrl=" + addSingleRecordingUrl);

	rmtQueue.addToQueue(addSingleRecordingUrl, function(json){ addedShowRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doSingleEpisodeRecord = function() {
	if(this.showID == -1)
		return;

	var deviceID = document.getElementById("epg-sheet-single-record-devices").options[this.seriesDeviceIndex].value

	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceID + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	addEpisodeRecordingUrl = host_url + '?op=' + 'ScheduleSeriesRecordingEpisode' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + deviceID + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[555]: doSingleEpisodeRecord: addEpisodeRecordingUrl=" + addEpisodeRecordingUrl);

	rmtQueue.addToQueue(addEpisodeRecordingUrl, function(json){ addedShowRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doSeriesEpisodeRecord = function() {
	if(this.showID == -1)
		return;

	var deviceID = document.getElementById("epg-sheet-single-record-devices").options[this.seriesDeviceIndex].value

	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceID + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	addEpisodeRecordingUrl = host_url + '?op=' + 'ScheduleSeriesRecordingEpisode' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + deviceID + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[569]: doSeriesEpisodeRecord: addEpisodeRecordingUrl=" + addEpisodeRecordingUrl);

	rmtQueue.addToQueue(addEpisodeRecordingUrl, function(json){ addedShowRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doAddFav = function() {
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'series_id' + this.seriesID + 'user_initiated' + 'true');
	addFavouriteUrl = host_url + '?op=' + 'AddFavorite' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_id=' + this.seriesID + '&user_initiated=' + 'true' + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[580]: doAddFav: addFavouriteUrl=" + addFavouriteUrl);

	rmtQueue.addToQueue(addFavouriteUrl, function(json){ addedFav(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doRemoveFav = function() {
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'series_id' + this.seriesID + 'user_initiated' + 'true');
	delFavouriteUrl = host_url + '?op=' + 'DeleteFavorite' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_id=' + this.seriesID + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[587]: doRemoveFav: delFavouriteUrl=" + delFavouriteUrl);

	rmtQueue.addToQueue(delFavouriteUrl, function(json){ deletedFav(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doRemoveKeyword = function() {
    api_check_delete = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'keyword_recording_id' + this.keywordRecordingID + 'user_initiated' + 'true');
    deleteKeywordRecordingUrl = host_url + '?op=' + 'DeleteKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordRecordingID + '&user_initiated=' + 'true' + '&api_check=' + api_check_delete; 

    DEBUGLOG("SheetManager.js[596]: doRemoveKeyword: deleteKeywordRecordingUrl=" + deleteKeywordRecordingUrl);

    rmtQueue.addToQueue(deleteKeywordRecordingUrl, function(json){ updatedKeywordRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.doKeywordRecordUpdate = function() {
	if(this.keywordRecordingID == -1)
		return;

    /**
     * Split search string into match and avoid patterns
     */
    var matchPattern;
    var tokenArray = smartSplit( " ", this.keywordRecordPattern, false, "\"", false );
    var idx=0;
    var numTokens = tokenArray.length;
    for(idx=0; idx<numTokens; idx++) {
            if(matchPattern != null)
                matchPattern += " ";
            else
                matchPattern = "";
            matchPattern += tokenArray[idx];
    }
    
    /**
     * give the pattern safe defaults if they are not needed.
     */
    if(matchPattern == null)
        matchPattern = "";

    // Network ID: 0 - Any, 1 - The one for this show
	var networkID;
	if(this.keywordNetworkIndex == 0)
		networkID = "-1";
    else
        networkID = document.getElementById("epg-sheet-keyword-record-networks").options[this.keywordNetworkIndex].value

    // Recording Quality: 0/1/2/3 - SD Only/Pref HD/Pref SD/ HD only
	var recordingQuality = this.keywordQualityIndex;

    var recordingsPerDay;
    if(this.keywordLimitIndex == 0)
        recordingsPerDay = 1;
    else if(this.keywordLimitIndex == 1)
        recordingsPerDay = 2;
    else if(this.keywordLimitIndex == 2)
        recordingsPerDay = 3;
    else if(this.keywordLimitIndex == 3)
        recordingsPerDay = 4;
    else if(this.keywordLimitIndex == 4)
        recordingsPerDay = 5;
    else 
        recordingsPerDay = 0;

	// first_runs_only: 0 - No, 1 - Yes	
    // NOTE: Position in the select list is reverse of variable
	var firstRunsOnly;
	if(this.keywordTypeIndex == 1)
		firstRunsOnly = "0";
	else
		firstRunsOnly = "1";

	// view_or_record: 0 - Favourite, 1 - Record	
    // NOTE: Position in the select list is reverse of variable
	var viewOrRecord;
	if(this.keywordActionIndex == 1)
		viewOrRecord = "0";
	else
		viewOrRecord = "1";

	var deviceIndex = document.getElementById("epg-sheet-keyword-record-devices").options[this.keywordDeviceIndex].value;

//    DEBUGLOG("KeywordRecordingID: " + this.keywordRecordingID);
//    DEBUGLOG("MatchPattern: " + matchPattern);
//    DEBUGLOG("NetworkID: " + networkID);
//    DEBUGLOG("RecordingQuality: " + recordingQuality);
//    DEBUGLOG("RecordingsPerDay: " + recordingsPerDay);
//    DEBUGLOG("FirstRunsOnly: " + firstRunsOnly);
//    DEBUGLOG("ViewOrRecord: " + viewOrRecord);
//    DEBUGLOG("DeviceIndex: " + deviceIndex);
            
    if(this.keywordRecordingID == null || this.keywordRecordingID == "") {
        // Add New Entry
        api_check_add = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceIndex + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'match_pattern' + matchPattern + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + recordingQuality + 'user_initiated' + 'true' + 'view_or_record' + viewOrRecord);
        addKeywordRecordingUrl = host_url + '?op=' + 'AddKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&device_id=' + deviceIndex + '&first_runs_only=' + firstRunsOnly + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordRecordingID + '&match_pattern=' + escape(matchPattern) + '&network_id=' + networkID + '&recordings_per_day=' + recordingsPerDay + '&recording_quality=' + recordingQuality + '&user_initiated=' + 'true' + '&view_or_record=' + viewOrRecord + '&api_check=' + api_check_add; 

        DEBUGLOG("SheetManager.js[704]: doKeywordRecordUpdate: addKeywordRecordingUrl=" + addKeywordRecordingUrl);

        rmtQueue.addToQueue(addKeywordRecordingUrl, function(json){ updatedKeywordRecording(json); });
    } else {
        /**
         * If Device is changed then we need to do a delete for the old keyword_record_id and an add of the new details.
         */
        var origDeviceLabel = this.keywordData['device_label'];
        var origDeviceIndex = dv.indexForName(origDeviceLabel);

        /**
         * We only care about device changes for a "Record" type keyword, the device is ignored for "Favourite" keywords.
         */ 
        /**
         * Device Changed?
         */
        if(deviceIndex != origDeviceIndex && viewOrRecord == 1) {
            // YES - Delete Old Entry
            api_check_delete = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'keyword_recording_id' + this.keywordRecordingID + 'user_initiated' + 'true');
            deleteKeywordRecordingUrl = host_url + '?op=' + 'DeleteKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordRecordingID + '&user_initiated=' + 'true' + '&api_check=' + api_check_delete; 

            DEBUGLOG("SheetManager.js[725]: doKeywordRecordUpdate: deleteKeywordRecordingUrl=" + deleteKeywordRecordingUrl);

            rmtQueue.addToQueue(deleteKeywordRecordingUrl, function(json){ updatedKeywordRecording(json); });

            // Add New Entry
            api_check_add = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceIndex + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'match_pattern' + matchPattern + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + recordingQuality + 'user_initiated' + 'true' + 'view_or_record' + viewOrRecord);
            addKeywordRecordingUrl = host_url + '?op=' + 'AddKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&device_id=' + deviceIndex + '&first_runs_only=' + firstRunsOnly + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordRecordingID + '&match_pattern=' + escape(matchPattern) + '&network_id=' + networkID + '&recordings_per_day=' + recordingsPerDay + '&recording_quality=' + recordingQuality + '&user_initiated=' + 'true' + '&view_or_record=' + viewOrRecord + '&api_check=' + api_check_add; 

            DEBUGLOG("SheetManager.js[733]: doKeywordRecordUpdate: addKeywordRecordingUrl=" + addKeywordRecordingUrl);

            rmtQueue.addToQueue(addKeywordRecordingUrl, function(json){ updatedKeywordRecording(json); });
        } else {
            // NO - Perform a "normal" update.
            api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'first_runs_only' + firstRunsOnly + 'format' + 'json' + 'keyword_recording_id' + this.keywordRecordingID + 'match_pattern' + matchPattern + 'network_id' + networkID + 'recordings_per_day' + recordingsPerDay + 'recording_quality' + recordingQuality + 'user_initiated' + 'true' + 'view_or_record' + viewOrRecord);
            updateKeywordRecordingUrl = host_url + '?op=' + 'UpdateKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&first_runs_only=' + firstRunsOnly + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordRecordingID + '&match_pattern=' + escape(matchPattern) + '&network_id=' + networkID + '&recordings_per_day=' + recordingsPerDay + '&recording_quality=' + recordingQuality + '&user_initiated=' + 'true' + '&view_or_record=' + viewOrRecord + '&api_check=' + api_check; 

            DEBUGLOG("SheetManager.js[741]: doKeywordRecordUpdate: updateKeywordRecordingUrl=" + updateKeywordRecordingUrl);

            rmtQueue.addToQueue(updateKeywordRecordingUrl, function(json){ updatedKeywordRecording(json); });
        }
    }

	this.closeSheet(0);
}



SheetManager.prototype.removeSeriesRecording = function() {
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'series_recording_id' + this.seriesInfo["series_recording_id"] + 'show_id' + this.showID + 'user_initiated' + 'true');
	delSeriesRecordingUrl = host_url + '?op=' + 'DeleteSeriesRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&series_recording_id=' + this.seriesInfo["series_recording_id"] + '&show_id=' + this.showID + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[742]: removeSeriesRecording: delSeriesRecordingUrl=" + delSeriesRecordingUrl);
	rmtQueue.addToQueue(delSeriesRecordingUrl, function(json){ deletedSeriesRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.removeEpisodeRecording = function() {
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + this.seriesInfo["episode_device"] + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	delEpisodeUrl = host_url + '?op=' + 'CancelSeriesRecordingEpisode' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + this.seriesInfo["episode_device"] + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[754]: removeEpisodeRecording: delEpisodeUrl=" + delEpisodeUrl);
	rmtQueue.addToQueue(delEpisodeUrl, function(json){ deletedEpisodeRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.removeKeywordEpisodeRecording = function() {
	var upcomingRecord = mgu.recordForShowID(this.showID);
	if(!upcomingRecord)
		return;
		
	var device_label = upcomingRecord["device_label"];
    var deviceIndex = dv.indexForName(device_label);
    if(deviceIndex < 0) deviceIndex = 0;
    
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + deviceIndex + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	delEpisodeUrl = host_url + '?op=' + 'CancelKeywordRecordingEpisode' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + deviceIndex + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[801]: removeKeywordEpisodeRecording: delEpisodeUrl=" + delEpisodeUrl);
	rmtQueue.addToQueue(delEpisodeUrl, function(json){ deletedKeywordRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.removeKeywordRecording = function() {
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'format' + 'json' + 'keyword_recording_id' + this.keywordData['keyword_recording_id'] + 'user_initiated' + 'true');
	delKeywordRecordingUrl = host_url + '?op=' + 'DeleteKeywordRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&keyword_recording_id=' + this.keywordData['keyword_recording_id'] + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[764]: removeKeywordRecording: delKeywordRecordingUrl=" + delKeywordRecordingUrl);
	rmtQueue.addToQueue(delKeywordRecordingUrl, function(json){ deletedKeywordRecording(json); });

	this.closeSheet(0);
}

SheetManager.prototype.removeShowRecording = function() {
//	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + this.seriesInfo["episode_device"] + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
//	delEpisodeUrl = host_url + '?op=' + 'CancelSeriesRecordingEpisode' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + this.seriesInfo["episode_device"] + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 
	api_check = hex_sha1(api_secret + 'api_version' + widgetApiVersion + 'application_name' + widgetApplicationName + 'application_version' + widgetVersion + 'auth_token' + ath.authToken + 'device_id' + this.seriesInfo["episode_device"] + 'format' + 'json' + 'show_id' + this.showID + 'user_initiated' + 'true');
	delEpisodeUrl = host_url + '?op=' + 'DeleteSingleRecording' + '&api_key=' + api_key + '&api_version=' + widgetApiVersion + '&application_name=' + widgetApplicationName + '&application_version=' + widgetVersion + '&auth_token=' + ath.authToken + '&format=' + 'json' + '&show_id=' + this.showID + '&device_id=' + this.seriesInfo["episode_device"] + '&user_initiated=' + 'true'  + '&api_check=' + api_check; 

    DEBUGLOG("SheetManager.js[774]: removeShowRecording: delEpisodeUrl=" + delEpisodeUrl);
	rmtQueue.addToQueue(delEpisodeUrl, function(json){ deletedEpisodeRecording(json); });

	this.closeSheet(0);
}



SheetManager.prototype.setSeriesOptionsMode = function(mode){
	if(mode == 1){
		document.getElementById("epg-sheet-series-record-networks").style.display = "block"
		document.getElementById("epg-sheet-series-record-time-menu").style.display = "none"
		document.getElementById("epg-sheet-series-container").setAttribute("class", "sheet-record-series-series");
	} else {
		document.getElementById("epg-sheet-series-record-networks").style.display = "block"
		document.getElementById("epg-sheet-series-record-time-menu").style.display = "block"
		document.getElementById("epg-sheet-series-container").setAttribute("class", "sheet-record-series");
	}
}

SheetManager.prototype.setKeywordOptionsMode = function(mode){
//    DEBUGLOG("SheetManager.js[463]: setKeywordOptionsMode: mode: " + mode);
	document.getElementById("epg-sheet-keyword-container").setAttribute("class", "sheet-record-keyword");
}


SheetManager.prototype.changeKeywordRecordDevice = function(index) {
//    DEBUGLOG("SheetManager.js[705]: changeKeywordRecordDevice: " + index);
	this.keywordDeviceIndex = index;
	document.getElementById("epg-sheet-keyword-record-device").innerText = document.getElementById("epg-sheet-keyword-record-devices").options[index].text;
	document.getElementById("epg-sheet-keyword-record-devices").selectedIndex = index;
}

SheetManager.prototype.changeKeywordRecordAction = function(index) {
    DEBUGLOG("SheetManager.js[712]: changeKeywordRecordAction: " + index);
	document.getElementById("epg-sheet-keyword-record-action").innerText = document.getElementById("epg-sheet-keyword-record-action-menu").options[index].text;
	document.getElementById("epg-sheet-keyword-record-action-menu").selectedIndex = index;
	this.keywordActionIndex = index;

    if(index == 0) { // Record
        document.getElementById("epg-sheet-keyword-container").setAttribute("class", "sheet-record-keyword");
        document.getElementById("epg-sheet-keyword-record-devices").style.display = "block";
    } else { 
        document.getElementById("epg-sheet-keyword-container").setAttribute("class", "sheet-record-keyword-favourite");
        document.getElementById("epg-sheet-keyword-record-devices").style.display = "none";
    }
}

SheetManager.prototype.changeKeywordRecordNetwork = function(index) {
//    DEBUGLOG("SheetManager.js[719]: changeKeywordRecordNetwork: " + index);
	document.getElementById("epg-sheet-keyword-record-network").innerText = document.getElementById("epg-sheet-keyword-record-networks").options[index].text;
	document.getElementById("epg-sheet-keyword-record-networks").selectedIndex = index;
	this.keywordNetworkIndex = index;
}

SheetManager.prototype.changeKeywordRecordPattern = function() {
//    DEBUGLOG("SheetManager.js[733]: changeKeywordRecordPattern");
	this.keywordRecordPattern = document.getElementById("epg-sheet-keyword-record-pattern").value;
}

SheetManager.prototype.changeKeywordRecordQuality = function(index) {
//    DEBUGLOG("SheetManager.js[738]: changeKeywordRecordQuality: " + index);
	document.getElementById("epg-sheet-keyword-record-quality").innerText = document.getElementById("epg-sheet-keyword-record-quality-menu").options[index].text;
	document.getElementById("epg-sheet-keyword-record-quality-menu").selectedIndex = index;
	this.keywordQualityIndex = index;
}

SheetManager.prototype.changeKeywordRecordType = function(index) {
//    DEBUGLOG("SheetManager.js[745]: changeKeywordRecordType: " + index);
	document.getElementById("epg-sheet-keyword-record-type").innerText = document.getElementById("epg-sheet-keyword-record-type-menu").options[index].text;
	document.getElementById("epg-sheet-keyword-record-type-menu").selectedIndex = index;
	this.keywordTypeIndex = index;
}

SheetManager.prototype.changeKeywordRecordLimit = function(index) {
//    DEBUGLOG("SheetManager.js[752]: changeKeywordRecordLimit: " + index);
	document.getElementById("epg-sheet-keyword-record-limit").innerText = document.getElementById("epg-sheet-keyword-record-limit-menu").options[index].text;
	document.getElementById("epg-sheet-keyword-record-limit-menu").selectedIndex = index;
	this.keywordLimitIndex = index;
}

SheetManager.prototype.changeSeriesRecordDevice = function(index) {
	this.seriesDeviceIndex = index;
	document.getElementById("epg-sheet-single-record-device").innerText = document.getElementById("epg-sheet-single-record-devices").options[index].text;
	document.getElementById("epg-sheet-single-record-devices").selectedIndex = index;

	document.getElementById("epg-sheet-series-record-device").innerText = document.getElementById("epg-sheet-single-record-devices").options[index].text;
	document.getElementById("epg-sheet-series-record-devices").selectedIndex = index;
}

SheetManager.prototype.changeSeriesRecordTime = function(index) {
    DEBUGLOG("SheetManager.js[964]: changeSeriesRecordTime: " + index);
	document.getElementById("epg-sheet-series-record-time").innerText = document.getElementById("epg-sheet-series-record-time-menu").options[index].text;
	document.getElementById("epg-sheet-series-record-time-menu").selectedIndex = index;
	this.seriesTimeIndex = index;
}

SheetManager.prototype.changeSeriesRecordNetwork = function(index) {
//   DEBUGLOG("SheetManager.js[828]: changeSeriesRecordNetwork: " + index);
	document.getElementById("epg-sheet-series-record-network").innerText = document.getElementById("epg-sheet-series-record-networks").options[index].text;
	document.getElementById("epg-sheet-series-record-networks").selectedIndex = index;
	this.seriesNetworkIndex = index;
}

SheetManager.prototype.changeSeriesRecordQuality = function(index) {
	document.getElementById("epg-sheet-series-record-quality").innerText = document.getElementById("epg-sheet-series-record-quality-menu").options[index].text;
	document.getElementById("epg-sheet-series-record-quality-menu").selectedIndex = index;
	this.seriesQualityIndex = index;
}

SheetManager.prototype.changeSeriesRecordType = function(index) {
	document.getElementById("epg-sheet-series-record-type").innerText = document.getElementById("epg-sheet-series-record-type-menu").options[index].text;
	document.getElementById("epg-sheet-series-record-type-menu").selectedIndex = index;
	this.seriesTypeIndex = index;
}

SheetManager.prototype.changeSeriesRecordLimit = function(index) {
	document.getElementById("epg-sheet-series-record-limit").innerText = document.getElementById("epg-sheet-series-record-limit-menu").options[index].text;
	document.getElementById("epg-sheet-series-record-limit-menu").selectedIndex = index;
	this.seriesLimitIndex = index;
}

SheetManager.prototype.manuallyOpenedSheet = function(sheetID) {
	if(sheetID == 1)
		this.updateSheetActive = true;
}

SheetManager.prototype.showSheet = function(sheetID, callback) {	
	if(sheetID == 0){
		resizeFront(parseInt(document.getElementById("sheet-container").style.height, 10) + 72);
		var slide = new AnimationObject(document.getElementById("epg-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet").style.top, 10), 0, 10, 0, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushGroup(Array(slide));
		this.animator.prepare(200, 10);
		this.animator.run();

		this.epgSheetActive = true;
	}
	if(sheetID == 1){
		resizeFront(parseInt(document.getElementById("sheet-container").style.height, 10) + 72);
		var slide = new AnimationObject(document.getElementById("critical-update-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("critical-update-sheet").style.top, 10), 0, 10, 0, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushGroup(Array(slide));
		this.animator.prepare(200, 10);
		this.animator.run();

		this.updateSheetActive = true;
	}
	if(sheetID == 2){
		resizeFront(parseInt(document.getElementById("sheet-container").style.height, 10) + 72);
		var slide = new AnimationObject(document.getElementById("extraDays_sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("extraDays_sheet").style.top, 10), 0, 10, 0, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushGroup(Array(slide));
		this.animator.prepare(200, 10);
		this.animator.run();
		this.extraDaysSheetActive = true;
	}
	if(sheetID == 3){
		resizeFront(parseInt(document.getElementById("sheet-container").style.height, 10) + 72);
		var slide = new AnimationObject(document.getElementById("welcome-subscrive-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("welcome-subscrive-sheet").style.top, 10), 0, 10, 0, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushGroup(Array(slide));
		this.animator.prepare(200, 10);
		this.animator.run();

		this.authWelcomeSheetActive = true;
	}
}

SheetManager.prototype.isActive = function() {
	if(this.epgSheetActive == true || this.updateSheetActive == true || this.extraDaysSheetActive || this.authWelcomeSheetActive)
		return true;
	return false;
}

SheetManager.prototype.activeHeight = function() {
	if(this.epgSheetActive == true)
		return parseInt(document.getElementById("sheet-container").style, 10) + 72;
	if(this.updateSheetActive == true)
		return parseInt(document.getElementById("sheet-container").style, 10) + 72;
	if(this.extraDaysSheetActive == true)
		return parseInt(document.getElementById("sheet-container").style, 10) + 72;
	if(this.authWelcomeSheetActive == true)
		return parseInt(document.getElementById("sheet-container").style, 10) + 72;
	return -1;
}

SheetManager.prototype.forceCloseSheets = function() {
	var container;
	if(selectedPage == 0)
		container = document.getElementById("epg_container");
	else if(selectedPage == 1)
		container = document.getElementById("popular_container");
	else if(selectedPage == 2)
		container = document.getElementById("myguideupcoming_container");
	else if(selectedPage == 3)
		container = document.getElementById("myguideseries_container");
	else if(selectedPage == 4)
		container = document.getElementById("recommended_container");
	
	if(container)
		container.style.opacity = 1;

	if(this.epgSheetActive == true){
		this.epgSheetActive = false;
		document.getElementById("epg-sheet").style.display = "none";;
	}

	if(this.updateSheetActive == true){
		this.updateSheetActive = false;
		document.getElementById("critical-update-sheet").style.display = "none";;
	}

	if(this.extraDaysSheetActive == true){
		this.extraDaysSheetActive = false;
		document.getElementById("extraDays_sheet").style.display = "none";;
	}

	if(this.authWelcomeSheetActive == true){
		this.authWelcomeSheetActive = false;
		document.getElementById("welcome-subscrive-sheet").style.display = "none";;
	}

	document.getElementById("welcome-sheet").style.display = "none";
	document.getElementById("auth-expired-sheet").style.display = "none";
	document.getElementById("sheet-container").style.display = "none";
}

SheetManager.prototype.closeSheet = function(sheetID) {
	if(sheetID == 0){
		this.epgSheetActive = false;
	}
	
	if(sheetID == 1){
		this.updateSheetActive = false;
	}

	
	if(sheetID == 2){
		this.extraDaysSheetActive = false;
	}

	if(sheetID == 3){
		this.authWelcomeSheetActive = false;
	}
	
	var container;
	if(selectedPage == 0)
		container = document.getElementById("epg_container");
	else if(selectedPage == 1)
		container = document.getElementById("popular_container");
	else if(selectedPage == 2)
		container = document.getElementById("myguideupcoming_container");
	else if(selectedPage == 3)
		container = document.getElementById("myguideseries_container");
	else if(selectedPage == 4)
		container = document.getElementById("recommended_container");
	
	container.style.opacity = 1;

	var _self = this;

	if(sheetID == 0){
		this.epgSheetActive = false;

		var slide = new AnimationObject(document.getElementById("epg-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("epg-sheet").style.top, 10), -parseInt(document.getElementById("sheet-container").style.height, 10), 10, 0, null)

		var hide = new AnimationObject(document.getElementById("sheet-container"));
		hide.setOptions(kAnimateOptionsHide, 10);
		hide.pushPhase(0, 0, 0, 1, 9, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushCallback(function(){ resizeWindowAfterPageSwitch(); });
		this.animator.pushCallback(function(){ _self.sheetCloseComplete(sheetID); });
		this.animator.pushGroup(Array(slide, hide));
		this.animator.prepare(200, 10);
		this.animator.run();
	}
	
	if(sheetID == 1){
		var slide = new AnimationObject(document.getElementById("critical-update-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("critical-update-sheet").style.top, 10), -parseInt(document.getElementById("sheet-container").style.height, 10), 10, 0, null)

		var hide = new AnimationObject(document.getElementById("sheet-container"));
		hide.setOptions(kAnimateOptionsHide, 10);
		hide.pushPhase(0, 0, 0, 1, 9, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushCallback(function(){ resizeWindowAfterPageSwitch(); });
		this.animator.pushCallback(function(){ _self.sheetCloseComplete(sheetID); });
		this.animator.pushGroup(Array(slide, hide));
		this.animator.prepare(200, 10);
		this.animator.run();

		this.updateSheetActive = false;
	}	

	if(sheetID == 2){
		var slide = new AnimationObject(document.getElementById("extraDays_sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("extraDays_sheet").style.top, 10), -parseInt(document.getElementById("sheet-container").style.height, 10), 10, 0, null)

		var hide = new AnimationObject(document.getElementById("sheet-container"));
		hide.setOptions(kAnimateOptionsHide, 10);
		hide.pushPhase(0, 0, 0, 1, 9, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushCallback(function(){ resizeWindowAfterPageSwitch(); });
		this.animator.pushCallback(function(){ _self.sheetCloseComplete(sheetID); });
		this.animator.pushGroup(Array(slide, hide));
		this.animator.prepare(200, 10);
		this.animator.run();

		this.extraDaysSheetActive = false;
	}	

	if(sheetID == 3){
		this.authWelcomeSheetActive = false;
		var slide = new AnimationObject(document.getElementById("welcome-subscrive-sheet"));
		slide.setOptions(0, 10);
		slide.pushPhase(kAnimatorMoveVerticalTop, parseInt(document.getElementById("welcome-subscrive-sheet").style.top, 10), -parseInt(document.getElementById("sheet-container").style.height, 10), 10, 0, null)

		var hide = new AnimationObject(document.getElementById("sheet-container"));
		hide.setOptions(kAnimateOptionsHide, 10);
		hide.pushPhase(0, 0, 0, 1, 9, null)
	
		this.animator.purge();
		this.animator.purgeCallbacks();
		this.animator.pushCallback(function(){ resizeWindowAfterPageSwitch(); });
		this.animator.pushGroup(Array(slide, hide));
		this.animator.prepare(200, 10);
		this.animator.run();
	}	
}

SheetManager.prototype.sheetCloseComplete = function(sheetID) {
	document.getElementById("sheet-container").style.display = "none";
	if(sheetID == 0){
		document.getElementById("epg-sheet").style.display = "none";
		upd.epgSheetClosed();
	}
	if(sheetID == 1)
		document.getElementById("critical-update-sheet").style.display = "none";
	if(sheetID == 2)
		document.getElementById("extraDays_sheet").style.display = "none";
	if(sheetID == 3)
		document.getElementById("welcome-subscrive-sheet").style.display = "none";
}

SheetManager.prototype.highlightTitleUnderline = function() {
	for(x=0;x<this.titleUnderlines.length;x++){
		this.titleUnderlines[x].src = "images/modes/underline_hightlighted.png"
	}
}

SheetManager.prototype.dehighlightTitleUnderline = function() {
	for(x=0;x<this.titleUnderlines.length;x++){
		this.titleUnderlines[x].src = "images/modes/underline.png"
	}
}

SheetManager.prototype.fillEpgSheetDetailsSecondary_OLD = function(updateonly, title, subtitle, year, time, additional, description, isFav, recordData, seriesRecordData, isRecommended, partOfSeries, canRecordSingle, isKeyword, viewOrRecord, keywordData) {
//    DEBUGLOG("fillEpgSheetDetailsSecondary(" + updateonly + ", " + title + ", " + subtitle + ", " + year + ", " + time + ", " + additional + ", " + description + ", " + isFav + ", " + recordData + ", " + seriesRecordData + ", " + isRecommended + ", " + partOfSeries + ", " + canRecordSingle + ", " + isKeyword + ", " + viewOrRecord + ", " + keywordData + ")");
    DEBUGLOG("fillEpgSheetDetailsSecondary(" + isFav + ", " + recordData + ", " + seriesRecordData + ", " + isRecommended + ", " + partOfSeries + ", " + canRecordSingle + ", " + isKeyword + ", " + viewOrRecord + ", " + keywordData + ")");

	var offset = 0;
	var _self = this;
	
    /******************************************************************************
     * Close any open sheets
     ******************************************************************************/
	sht.forceCloseSheets();

    /******************************************************************************
     * Hide Action Buttons, ie Add Favourite etc
     ******************************************************************************/
   document.getElementById("sheet_button_addfav"       ).style.display = "none";
   document.getElementById("sheet_button_deletefav"    ).style.display = "none";
   document.getElementById("sheet_button_createkeyword").style.display = "none";
   document.getElementById("sheet_button_recordkeyword").style.display = "none";   // "RecordKeyword"
   document.getElementById("sheet_button_updatekeyword").style.display = "none";   // "UpdateKeyword"
   document.getElementById("sheet_button_deletekeyword").style.display = "none";   // "DeleteKeyword"
   document.getElementById("sheet_button_recordseries" ).style.display = "none";   // "RecordSeries"
   document.getElementById("sheet_button_updateseries" ).style.display = "none";   // "UpdateSeries"
   document.getElementById("sheet_button_recordonce"   ).style.display = "none";   // "RecordOnce"
//   document.getElementById("sheet-keyword-delete-buttons").style.display = "none";  

    /******************************************************************************
     * Hide Options Panels, ie "Single Record Options"
     ******************************************************************************/
	document.getElementById("epg-sheet-single-record-options").style.display    = "none"; // Single Recording Options Panel
	document.getElementById("epg-sheet-series-record-options").style.display    = "none"; // Series Recording Options Panel
	document.getElementById("epg-sheet-keyword-record-options").style.display   = "none"; // Keyword Recording Options Panel
    

    /******************************************************************************
     * Show Buttons Panel, contains the buttons for Single Record etc
     ******************************************************************************/
	document.getElementById("epg-sheet-buttons").style.opacity = 1;
	document.getElementById("sheet-rec-controls-divider").style.opacity = 1;
	document.getElementById("sheet-rec-controls-divider").style.display = "block";
	document.getElementById("sheet-rec-delete-buttons").style.opacity = 1
	document.getElementById("sheet-rec-delete-buttons").style.display = "block"

    
    /******************************************************************************
     * Show Detail Sheet
     ******************************************************************************/
	document.getElementById("epg-sheet").style.opacity = 0;
	document.getElementById("epg-sheet").style.display = "block"
	document.getElementById("sheet-container").style.display = "block"
	
    /******************************************************************************
     * Fill in Detail Sheet Information, title, subtitle etc
     ******************************************************************************/
	document.getElementById("epg-sheet-show-name").innerHTML = title;
	if(year && year.length == 4)
		document.getElementById("epg-sheet-show-name").innerHTML += " (" + year + ")";
	
	if(subtitle)
		document.getElementById("epg-sheet-show-episode-container").style.display = "block";
	else
		document.getElementById("epg-sheet-show-episode-container").style.display = "none";
		
	if(time || additional)
		document.getElementById("epg-sheet-show-time-container").style.display = "block";
	else
		document.getElementById("epg-sheet-show-time-container").style.display = "none";
		
	document.getElementById("epg-sheet-show-episode").innerHTML = subtitle;
	document.getElementById("epg-sheet-show-time").innerText = time;
	if(time && additional)
		document.getElementById("epg-sheet-show-time").innerText += "\n";
	document.getElementById("epg-sheet-show-description").innerHTML = description;
	if(epg.mode != "7")
		document.getElementById("epg-sheet-show-description").innerHTML += "<br/><div style='padding-top:5px;line-height:10px;'><small>To record this show on your media center PC, Mac or PVR, subscribe to IceTV.</small></div>";

	document.getElementById("epg-sheet-show-additional").innerText = additional
	
    /******************************************************************************
     * Fill in Pills & Buttons
     *
     * Cases
     * -----
     *
     * Case 1: Not a recording
     *         !recordData && !seriesRecordData && !keywordRecordData
     *
     * Case 2: Single recording (Not part of a keyword or series)
     *         recordData && !seriesRecordData && !keywordRecordData
     *
     * Case 3: Series recording, scheduled
     *         !recordData && seriesRecordData && !keywordRecordData && seriesRecordData["is_scheduled"]
     *
     * Case 4: Series recording, not scheduled
     *         !recordData && seriesRecordData && !keywordRecordData && !seriesRecordData["is_scheduled"]
     *
     * Case 5: Keyword Recording
     *         !recordData && !seriesRecordData && keywordRecordData && keywordRecordData["viewOrRecord"]
     *
     * Case 6: Keyword Favourite
     *         !recordData && !seriesRecordData && keywordRecordData && !keywordRecordData["viewOrRecord"]
     *
     * NOTE: It is possible in all 6 states to be classed as a Favourite, this 
     *       affects the pills displayed as well as the type of favourite button 
     *       that is displayed.
     *
     * NOTE: It is possible in all 6 states to be classed as a Recommended item, this 
     *       affects the pills displayed.
     *
     * Parameters
     * ----------
     * updateonly: 			ALWAYS FALSE!!!
     *
     * title: 				The series name for the show, ie "The Simpsons". 
     *		  				For keyword recordings it is the text "Keyword recording for"
     *
     * subtitle: 			The episode name for the show, ie "Homer kills everyone"
     *					 	For keyword recordings it is the query string "Foo -Bar"
     *
     * year: 				Year of production (for Movies)
     *
     * time: 				Start time of program
     *
     * additional: 			Program ratings and flags, ie PG, CC, WS
     *
     * description: 		The description of the program
     *
     * isFav: 				true if the program is marked as a Favourite, false otherwise
     *
     * recordData: 			Array of data for a single recording
     *
     * seriesRecordData: 	Array of data for a series recording 
     *
     * isRecommended: 		true if the program is marked as a recommendation, false otherwise
     *
     * partOfSeries: 		true if the program is part of a series recording, false otherwise
     *
     * canRecordSingle: 	true from TVGuide, false otherwise
     *
     * isKeyword: 			true if the program is matched by a keyword recording/fav, false otherwise
     *
     * viewOrRecord: 		true for a keyword recording, false for a keyword favourite
     *
     * keywordRecordData: 	Array of data for a keyword recording/favourite
     * 
     ******************************************************************************/
    
	if(seriesRecordData){
		document.getElementById("epg_sheet_pill_series").style.display = "inline";
		document.getElementById("epg_sheet_pill_series_cancel").style.display = "none";
        document.getElementById("epg_sheet_pill_keyrec").style.display = "none";
        document.getElementById("epg_sheet_pill_single").style.display = "none";
	} else {
		document.getElementById("epg_sheet_pill_series").style.display = "none";
		document.getElementById("epg_sheet_pill_series_cancel").style.display = "none";

        if(recordData){
            document.getElementById("epg_sheet_pill_single").style.display = "inline";
        } else {
            document.getElementById("epg_sheet_pill_single").style.display = "none";
            if(partOfSeries)
                document.getElementById("epg_sheet_pill_series_cancel").style.display = "inline";
        }

        if((recordData && recordData['is_keyword'] == "1" && recordData['view_or_record'] == "1") || (isKeyword && viewOrRecord && isKeyword == "1" && viewOrRecord == "1")){
            document.getElementById("epg_sheet_pill_keyrec").style.display = "inline";
        } else
            document.getElementById("epg_sheet_pill_keyrec").style.display = "none";
    }

    if((recordData && recordData['is_keyword'] == "1" && recordData['view_or_record'] == "0") || (isKeyword && viewOrRecord && isKeyword == "1" && viewOrRecord == "0")){
        document.getElementById("epg_sheet_pill_keyfav").style.display = "inline";
    } else
        document.getElementById("epg_sheet_pill_keyfav").style.display = "none";

	if(isFav){
		document.getElementById("epg_sheet_pill_fav").style.display = "inline";
	} else
		document.getElementById("epg_sheet_pill_fav").style.display = "none";

	if(isRecommended){
		document.getElementById("epg_sheet_pill_recommended").style.display = "inline";
	} else
		document.getElementById("epg_sheet_pill_recommended").style.display = "none";
	
/*------------- BUTTONS ----------------------------------*/

    /**
     * Add Fav Button if needed
     */
	if(!isFav){
		document.getElementById("sheet_button_addfav").style.display = "block"
		document.getElementById("sheet_button_deletefav").style.display = "none"
	} else {
		document.getElementById("sheet_button_deletefav").style.display = "block"
		document.getElementById("sheet_button_addfav").style.display = "none"
	}
    
    
    /**
     * Clear Delete Series/Ep Buttons
     */
	while(document.getElementById("epg-sheet-record-locations").hasChildNodes())
		document.getElementById("epg-sheet-record-locations").removeChild(document.getElementById("epg-sheet-record-locations").firstChild);
		
    /**
     * Set Title in Single or Series Panel
     */
    document.getElementById("epg-sheet-single-record-showtitle").innerHTML = title;
	document.getElementById("epg-sheet-series-record-showtitle").innerHTML = title;

	if(epg.mode == "7"){
		document.getElementById("sheet_button_recordseries").setAttribute("onclick", "sht.showRecordSeriesOptions()");
		document.getElementById("sheet_button_updateseries").setAttribute("onclick", "sht.showUpdateSeriesOptions()");

		document.getElementById("sheet_button_recordseries").style.opacity = 1.0
		document.getElementById("sheet_button_updateseries").style.opacity = 1.0
	} else {
		document.getElementById("sheet_button_recordseries").setAttribute("onclick", "");
		document.getElementById("sheet_button_updateseries").setAttribute("onclick", "");

		document.getElementById("sheet_button_recordseries").style.opacity = 0.5
		document.getElementById("sheet_button_updateseries").style.opacity = 0.5
	}

    /**
     * Is this an existing single or series recording?
     */
	if(seriesRecordData || recordData){				// YES
        /**
         * Series Recording
         */
		if(seriesRecordData){ 
			document.getElementById("series_record_label_type").innerText = "update";

            /**
             * Enable "UpdateSeries"
             */
			document.getElementById("sheet-update-series-button-update").style.display = "block";
			document.getElementById("sheet_button_updateseries").style.display = "block";
			document.getElementById("sheet_button_updateseries").style.opacity = 1.0;

            /**
             * Disable "RecordOnce", but leave disabled button visible
             */
			document.getElementById("sheet_button_recordonce").style.display = "block";
			document.getElementById("sheet_button_recordonce").style.opacity = 0.5;
			
			if(!isFav)
				document.getElementById("sheet_button_recordonce").style.left = "102px";
			else
				document.getElementById("sheet_button_recordonce").style.left = "112px";


			var deviceID = dv.indexForName(seriesRecordData['device_label']);
			var foundDevice = false;
			for(var i=0;i<document.getElementById("epg-sheet-single-record-devices").options.length;i++){
				if(document.getElementById("epg-sheet-single-record-devices").options[i].value == deviceID){
					foundDevice = true;
					this.changeSeriesRecordDevice(i);
					break;
				}
			}
			if(!foundDevice){
				if(document.getElementById("epg-sheet-single-record-devices").options.length > 0)
					this.changeSeriesRecordDevice(0);
			}
		
			// first_runs_only 0/1 maps to "First runs"/"First & reruns" which are indexes 0/1
			if(seriesRecordData['first_runs_only'] == "0")
				this.changeSeriesRecordType(1);
			else
				this.changeSeriesRecordType(0);

			// network_id XX/-1 maps to "This network"/"Any network" which are indexes 0/1
			if(seriesRecordData['network_id'] == "-1")
				this.changeSeriesRecordNetwork(0);
		
			//start_minutes -1/XX maps to "Any time"/"This time" which are indexes 0/1
			if(seriesRecordData['start_minutes'] == "-1")
				this.changeSeriesRecordTime(0);
			else
				this.changeSeriesRecordTime(1);

            this.changeSeriesRecordQuality(seriesRecordData['recording_quality']);

            /**
             * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
             * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
             */
            var recordingsPerDay;
            if(seriesRecordData['recordings_per_day'] == "0")
                recordingsPerDay = 5;
            else {
                recordingsPerDay = seriesRecordData['recordings_per_day'] - 1;
            }
            this.changeSeriesRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL
        
			this.seriesRecordID = seriesRecordData['series_recording_id'];
			this.seriesInfo["series_recording_id"] = seriesRecordData['series_recording_id']

			var deletebutton = document.createElement("div");
			deletebutton.setAttribute("class", "deleterecording");
			deletebutton.setAttribute("onclick", "sht.removeSeriesRecording()");
			document.getElementById("epg-sheet-record-locations").appendChild(deletebutton);

			this.seriesInfo["series_device"] = dv.indexForName(seriesRecordData['device_label']);

            /**
             * Create "Delete Series" button
             */
			var seriesrecordplace = document.createElement("div");
			seriesrecordplace.innerHTML = "Series scheduled to record on " + seriesRecordData["device_label"];
			seriesrecordplace.style.font = "bold 10px Lucida Grande, Tahoma Bold"
			seriesrecordplace.style.textAlign = "left";
			seriesrecordplace.style.position = "absolute";
			seriesrecordplace.style.left = "16px";
			seriesrecordplace.style.top = "1px";
			seriesrecordplace.style.color = "#ffffff";
			seriesrecordplace.style.width = "275px";
			document.getElementById("epg-sheet-record-locations").appendChild(seriesrecordplace);

			if(recordData){
				this.seriesInfo["episode_device"] = dv.indexForName(recordData['device_label'])

				var deletebutton = document.createElement("div");
				deletebutton.setAttribute("class", "deleterecording");
				deletebutton.onClick = function(){ _self.removeEpisodeRecording(); }
				deletebutton.setAttribute("onclick", "sht.removeEpisodeRecording()");
				deletebutton.style.top = "16px";
				document.getElementById("epg-sheet-record-locations").appendChild(deletebutton);
	
				var seriesrecordplace = document.createElement("div");
				seriesrecordplace.innerHTML = "Episode scheduled to record on " + recordData["device_label"];
				seriesrecordplace.style.font = "bold 10px Lucida Grande, Tahoma Bold"
				seriesrecordplace.style.textAlign = "left";
				seriesrecordplace.style.position = "absolute";
				seriesrecordplace.style.left = "16px";
				seriesrecordplace.style.top = "16px";
				seriesrecordplace.style.color = "#ffffff";
				seriesrecordplace.style.width = "275px";
				document.getElementById("epg-sheet-record-locations").appendChild(seriesrecordplace);
				
				document.getElementById("epg-sheet-record-locations").style.height = "30px";
			} else {
				document.getElementById("epg-sheet-record-locations").style.height = "15px";
			}				
		} else { 
            /**
             * NOTE: No Delete button is available as multiple keywords could match this show and
             * we have no easy way to select which one to delete.
             */
            var keywordrecordplace = document.createElement("div");
            keywordrecordplace.innerHTML        = "Keyword scheduled to record on " + recordData["device_label"];
            keywordrecordplace.style.font       = "bold 10px Lucida Grande, Tahoma Bold"
            keywordrecordplace.style.textAlign  = "left";
            keywordrecordplace.style.position   = "absolute";
            keywordrecordplace.style.left       = "16px";
            keywordrecordplace.style.top        = "1px";
            keywordrecordplace.style.color      = "#ffffff";
            keywordrecordplace.style.width      = "275px";
            document.getElementById("epg-sheet-record-locations").appendChild(keywordrecordplace);
            
            document.getElementById("epg-sheet-record-locations").style.height = "30px";

            /**
             * Single Recording
             */
			document.getElementById("series_record_label_type").innerText = "record";

            if(recordData && recordData['is_keyword'] == "1" && recordData['view_or_record'] == "1"){ // Keyword Recording
                this.keywordRecordID = recordData['keyword_recording_id'];

                if(recordData["part_of_series"] == "0") {
//                    document.getElementById("sheet-record-series-button-record").style.display = "block"
                    document.getElementById("sheet_button_recordseries").style.opacity = 1.0;
                    document.getElementById("sheet_button_recordseries").style.display = "block";
                    
                    /**
                     * Show "Record" button and hide "Update"
                     */
                    document.getElementById("sheet-record-series-button-record").style.display = "block"
                    document.getElementById("sheet-update-series-button-update").style.display = "none";
                    document.getElementById("series_record_label_type").innerText = "record";
                }
            }
            else {
                /**
                 * Display "RecordSeries"
                 */
                document.getElementById("sheet-record-series-button-record").style.display = "block"
                document.getElementById("sheet_button_recordseries").style.opacity = 1.0;
                document.getElementById("sheet_button_recordseries").style.display = "none";
            }


			if(document.getElementById("epg-sheet-single-record-devices").options.length > 0)
				this.changeSeriesRecordDevice(0);
			this.changeSeriesRecordType(0);
			this.changeSeriesRecordTime(0);
//			this.changeSeriesRecordNetwork(0);
			this.changeSeriesRecordQuality(1);
			this.changeSeriesRecordLimit(0);
			this.seriesInfo["episode_device"] = dv.indexForName(recordData['device_label'])

			var deletebutton = document.createElement("div");
			deletebutton.setAttribute("class", "deleterecording");
			deletebutton.setAttribute("onclick", "sht.removeShowRecording()");
			deletebutton.style.top = "16px";
			document.getElementById("epg-sheet-record-locations").appendChild(deletebutton);

			var seriesrecordplace = document.createElement("div");
			seriesrecordplace.innerHTML = "Episode scheduled to record on " + recordData["device_label"];
			seriesrecordplace.style.font = "bold 10px Lucida Grande, Tahoma Bold"
			seriesrecordplace.style.textAlign = "left";
			seriesrecordplace.style.position = "absolute";
			seriesrecordplace.style.left = "16px";
			seriesrecordplace.style.top = "16px";
			seriesrecordplace.style.color = "#ffffff";
			seriesrecordplace.style.width = "275px";
			document.getElementById("epg-sheet-record-locations").appendChild(seriesrecordplace);

			if(!isFav)
				document.getElementById("sheet_button_recordonce").style.left = "102px";
			else
				document.getElementById("sheet_button_recordonce").style.left = "112px";
            document.getElementById("epg-sheet-record-locations").style.height = "30px";
		}
    } else if(keywordData) { // Is this a keyword (on the My Shows page)
        if(keywordData['keyword_recording_id'] == 0) { // No existing keyword, this is a new keyword
            this.keywordRecordingID = ""; // Clear keywordRecordingID used in doKeywordRecordUpdate
            document.getElementById("keyword_record_label_type").innerText = "create";
            document.getElementById("sheet-record-keyword-button-create").style.display = "block";
            document.getElementById("sheet-record-keyword-button-update").style.display = "none";
        } else {
            document.getElementById("keyword_record_label_type").innerText = "update";
            document.getElementById("sheet-record-keyword-button-create").style.display = "none";
            document.getElementById("sheet-record-keyword-button-update").style.display = "block";
        }

        var lineText = keywordData["match_pattern"];
        if(keywordData["avoid_pattern"]){
            var avoidArray = smartSplit( " ", keywordData["avoid_pattern"], false, '"', false);
            lineText += " -" + avoidArray.join(" -");
        }
        document.getElementById("epg-sheet-keyword-record-showtitle").innerHTML = lineText;
		document.getElementById("epg-sheet-keyword-record-pattern").value = lineText;
        
        this.keywordRecordPattern = lineText;

        // view_or_record 0/1 maps to "Favourite"/"Record" which are indexes 0/1
        if(keywordData['view_or_record'] == "0") {
            this.changeKeywordRecordAction(1);
        } else {
            this.changeKeywordRecordAction(0);
        }

        // first_runs_only 0/1 maps to "First runs"/"First & reruns" which are indexes 0/1
        if(keywordData['first_runs_only'] == "0")
            this.changeKeywordRecordType(1);
        else
            this.changeKeywordRecordType(0);

        // network_id XX/-1 maps to "This network"/"Any network" which are indexes 0/1
        if(keywordData['network_id'] == "-1")
            this.changeKeywordRecordNetwork(0);
        else
            this.changeKeywordRecordNetwork(1);
    
        this.changeKeywordRecordQuality(keywordData['recording_quality']);

        /**
         * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
         * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
         */
        var recordingsPerDay;
        if(keywordData['recordings_per_day'] == "0")
            recordingsPerDay = 5;
        else {
            recordingsPerDay = keywordData['recordings_per_day'] - 1;
        }
        this.changeKeywordRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL

        /**
         * Hide Series Recording Options
         */
        document.getElementById("epg-sheet-series-record-options").style.display = "none"

        /**
         * Hide Keyword Recording Options
         */
        document.getElementById("epg-sheet-keyword-record-options").style.display = "none"

        /**
         * Display "Action Buttons"
         */
        if(keywordData['keyword_recording_id'] != 0) { 
            document.getElementById("sheet_button_deletekeyword").style.display = "block";
            document.getElementById("sheet_button_updatekeyword").style.display = "block";
        } else {
            document.getElementById("sheet_button_createkeyword").style.display = "block";
        }

        document.getElementById("sheet-rec-delete-buttons"  ).style.display = "block";
        
        /**
         * Disable comment link for keywords
         */
        document.getElementById("epg-sheet-iwt-comment").style.display = "none";
        
        var deviceID = dv.indexForName(keywordData['device_label']);
        var foundDevice = false;
        for(var i=0;i<document.getElementById("epg-sheet-keyword-record-devices").options.length;i++){
            if(document.getElementById("epg-sheet-keyword-record-devices").options[i].value == deviceID){
                foundDevice = true;
                this.changeKeywordRecordDevice(i);
                break;
            }
        }
        if(!foundDevice){
            if(document.getElementById("epg-sheet-keyword-record-devices").options.length > 0)
                this.changeKeywordRecordDevice(0);
        }
	} else {
        /**
         * Not a Single, Series or Keyword recording  
         */
		document.getElementById("sheet-record-series-button-record").style.display = "block"
		document.getElementById("sheet-update-series-button-update").style.display = "none";
		document.getElementById("series_record_label_type").innerText = "record";

		if(document.getElementById("epg-sheet-single-record-devices").options.length > 0)
			this.changeSeriesRecordDevice(0);

		this.changeSeriesRecordType(0);
		this.changeSeriesRecordTime(0);
//        this.changeSeriesRecordNetwork(0);
        this.changeSeriesRecordQuality(1);
        this.changeSeriesRecordLimit(0);
        
		document.getElementById("epg-sheet-record-locations").style.height = "0px";
		document.getElementById("sheet_button_recordseries").style.opacity = 1.0;
		document.getElementById("sheet_button_updateseries").style.display = "none";
		document.getElementById("sheet_button_recordonce").style.display = "block";
		document.getElementById("sheet_button_recordonce").style.opacity = 1;
		if(!isFav)
			document.getElementById("sheet_button_recordonce").style.left = "102px";
		else
			document.getElementById("sheet_button_recordonce").style.left = "112px";
		document.getElementById("sheet_button_recordseries").style.display = "block";
	}
    
	if(canRecordSingle && !recordData && epg.mode == "7"){
        /**
         * If this is part of a series but not scheduled then we are looking at a "non-matching" show
         * so we need the single record button and NOT the series record button
         */
        if(partOfSeries) { 
			document.getElementById("sheet-record-single-button-record").setAttribute("onclick", "sht.doSingleEpisodeRecord()");
            document.getElementById("sheet-record-series-button-record").style.display = "block"
            document.getElementById("sheet_button_recordseries").style.opacity = 0.5;
            document.getElementById("sheet_button_recordseries").setAttribute("onclick", "");
            document.getElementById("sheet_button_recordseries").style.display = "block";
        } 
        else 
			document.getElementById("sheet-record-single-button-record").setAttribute("onclick", "sht.doSingleShowRecord()");
		document.getElementById("sheet_button_recordonce").setAttribute("onclick", "sht.showRecordOnceOptions()");
		document.getElementById("sheet_button_recordonce").style.opacity = 1.0
	} else {
		document.getElementById("sheet_button_recordonce").style.opacity = 0.5
		document.getElementById("sheet_button_recordonce").setAttribute("onclick", "");
	}

	document.getElementById("epg-sheet-buttons").style.display = "block"
	var sheetTopHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),"").getPropertyValue("height"), 10);
	var sheetButtonsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),"").getPropertyValue("height"), 10);
	
//    DEBUGLOG("SheetManager[1741]: sheetTopHeight: " + sheetTopHeight);
//    DEBUGLOG("SheetManager[1742]: sheetButtonsHeight: " + sheetButtonsHeight);
//    DEBUGLOG("SheetManager[1743]: sheetBottomHeight: " + sheetBottomHeight);

	sheetHeight = sheetTopHeight + sheetButtonsHeight + sheetBottomHeight
//    DEBUGLOG("SheetManager[1746]: sheetHeight: " + sheetHeight);

	document.getElementById("epg-sheet-buttons").style.top = sheetTopHeight + "px"
	document.getElementById("epg-sheet-bottom").style.top = (sheetTopHeight + sheetButtonsHeight) + "px"
	
	
	document.getElementById("sheet-container").style.height = sheetHeight + "px"
	document.getElementById("epg-sheet").style.top = -sheetHeight + "px"
	document.getElementById("epg-sheet").style.opacity = 1;

	var container;
	if(selectedPage == 0)
		container = document.getElementById("epg_container");
	else if(selectedPage == 1)
		container = document.getElementById("popular_container");
	else if(selectedPage == 2)
		container = document.getElementById("myguideupcoming_container");
	else if(selectedPage == 3)
		container = document.getElementById("myguideseries_container");
	else if(selectedPage == 4)
		container = document.getElementById("recommended_container");
	
	container.style.opacity = 0.4;

	resizeFront(sheetHeight + 72);
	this.showSheet(0);

//    DEBUGLOG("SheetManager.js[1773]: epg-sheet: " + document.getElementById("epg-sheet").innerHTML);
}

SheetManager.prototype.fillEpgSheetDetailsSecondary = function(updateonly, title, subtitle, year, time, additional, description, isFav, recordData, seriesRecordData, isRecommended, partOfSeries, canRecordSingle, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData) {
//    DEBUGLOG("fillEpgSheetDetailsSecondary(" + updateonly + ", " + title + ", " + subtitle + ", " + year + ", " + time + ", " + additional + ", " + description + ", " + isFav + ", " + recordData + ", " + seriesRecordData + ", " + isRecommended + ", " + partOfSeries + ", " + canRecordSingle + ", " + isKeyword + ", " + viewOrRecord + ", " + keywordData + ")");
    DEBUGLOG("fillEpgSheetDetailsSecondary(" + isFav + ", " + recordData + ", " + seriesRecordData + ", " + isRecommended + ", " + partOfSeries + ", " + canRecordSingle + ", " + isKeyword + ", " + viewOrRecord + ", " + keywordData + ", " + epgData + ", " + popularData + ", " + recommendedData + ", " + favData + ")");

	var offset = 0;
	var _self = this;
    
/******************************************************************************
 * Close any open sheets
 ******************************************************************************/
	forceCloseSheets();

/******************************************************************************
 * Hide all buttons
 *
 *	BUTTON_ADD_FAV:
 *	BUTTON_DEL_FAV:
 *	BUTTON_RECORD_ONCE:
 *	BUTTON_RECORD_SERIES:
 *	BUTTON_UPDATE_SERIES:
 *	BUTTON_RECORD_KEYWORD:
 *	BUTTON_UPDATE_KEYWORD:
 *	BUTTON_DELETE_KEYWORD:
 *	BUTTON_CREATE_KEYWORD:
 *
 ******************************************************************************/
    setItemState(icetv.BUTTON_ADD_FAV,          icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_DEL_FAV,          icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_UPDATE_SERIES,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_RECORD_KEYWORD,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_UPDATE_KEYWORD,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_DELETE_KEYWORD,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_CREATE_KEYWORD,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_SINGLE_RECORD,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_SINGLE_CANCEL,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_SERIES_RECORD,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_SERIES_UPDATE,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_KEYWORD_RECORD,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_KEYWORD_UPDATE,   icetv.STATE_HIDDEN);
    setItemState(icetv.BUTTON_KEYWORD_CANCEL,   icetv.STATE_HIDDEN);



/******************************************************************************
 * Hide Delete Buttons
 ******************************************************************************/
    setItemState(icetv.SHOW_DELETE_BUTTONS,        icetv.STATE_HIDDEN);

/******************************************************************************
 * Hide Options Panels
 ******************************************************************************/
    setItemState(icetv.OPTION_SHEET_SINGLE,           icetv.STATE_HIDDEN);
    setItemState(icetv.OPTION_SHEET_SERIES,           icetv.STATE_HIDDEN);
    setItemState(icetv.OPTION_SHEET_KEYWORD,          icetv.STATE_HIDDEN);


/******************************************************************************
 * Clear Option Panel Info
 ******************************************************************************/
    setItemText(icetv.SINGLE_RECORD_LABEL_TYPE,       "");
    setItemText(icetv.SINGLE_RECORD_SHOWTITLE,        "");

    setItemText(icetv.SERIES_RECORD_LABEL_TYPE,       "");
    setItemText(icetv.SERIES_RECORD_SHOWTITLE,        "");

    setItemText(icetv.KEYWORD_RECORD_LABEL_TYPE,      "");
    setItemText(icetv.KEYWORD_RECORD_SHOWTITLE,       "");


/******************************************************************************
 * Clear Pills
 ******************************************************************************/
    setItemState(icetv.PILL_RECOMMENDED,          icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_SERIES,               icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_SERIES_CANCEL,        icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_SINGLE,               icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_KEYWORD_REC,          icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_KEYWORD_FAV,          icetv.STATE_HIDDEN);
    setItemState(icetv.PILL_FAVOURITE,            icetv.STATE_HIDDEN);

/******************************************************************************
 * Clear Show Info
 ******************************************************************************/
    setItemText( icetv.SHOW_TITLE,         "" );
    setItemText( icetv.SHOW_SUBTITLE,      "" );
    setItemText( icetv.SHOW_TIME,          "" );
    setItemText( icetv.SHOW_DESCRIPTION,   "" );
    setItemText( icetv.SHOW_ADDITIONAL,    "" );

/******************************************************************************
 * Clear Delete Buttons
 ******************************************************************************/
    clearDeleteButtons();

    DEBUGLOG("SheetManager.js[1215]: ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////");

/******************************************************************************
* Show Buttons Panel, contains the buttons for Single Record etc
******************************************************************************/
    setItemState(icetv.SHEET_BUTTONS,      icetv.STATE_VISIBLE);
    setItemState(icetv.SHEET_REC_DIVIDERS, icetv.STATE_VISIBLE);
    setItemState(icetv.SHEET_REC_BUTTONS,  icetv.STATE_VISIBLE);

    
/******************************************************************************
* Prepare Detail Sheet
******************************************************************************/
    setItemState   (icetv.EPG_SHEET,       icetv.STATE_VISIBLE);
    setItemOpacity (icetv.EPG_SHEET,       0                  );
    setItemState   (icetv.SHEET_CONTAINER, icetv.STATE_VISIBLE);


/******************************************************************************
* Prepare Options Sheets
******************************************************************************/
    this.changeSingleRecordDeviceFromMenu(0);   // First Device

    this.changeSeriesRecordDevice(0);   // First Device
    this.changeSeriesRecordTime(0);     // Any Time
    this.changeSeriesRecordType(0);     // First Runs
    this.changeSeriesRecordLimit(0);    // ALL
    this.changeSeriesRecordQuality(1);  // Prefer HD

    this.changeKeywordRecordDevice(0);   // First Device
    this.changeKeywordRecordType(0);     // First Runs
    this.changeKeywordRecordLimit(0);    // ALL
    this.changeKeywordRecordQuality(1);  // Prefer HD
    this.changeKeywordRecordAction(0);   // Keyword Recording


/******************************************************************************
 * Populate Sheet Info
 ******************************************************************************/
    setItemState(icetv.IWT_COMMENT, icetv.STATE_VISIBLE);

	if(year && year.length == 4)
        setItemText( icetv.SHOW_TITLE, title + " (" + year + ")" );
    else
        setItemText( icetv.SHOW_TITLE, title );
	
    setItemText( icetv.SHOW_SUBTITLE,      subtitle );
    setItemText( icetv.SHOW_TIME,          time );

	if(epg.mode != "7")
        setItemText( icetv.SHOW_DESCRIPTION,   description + "<br/><div style='padding-top:5px;line-height:10px;'><small>To record this show on your media center PC, Mac or PVR, subscribe to IceTV.</small></div>");
    else
        setItemText( icetv.SHOW_DESCRIPTION,   description );
		
    setItemText( icetv.SHOW_ADDITIONAL,    additional );

    if(isFav) {
/**
 *      PILL_FAVOURITE: YES
 *      BUTTON_DEL_FAV: YES
 */                
        setItemState(icetv.PILL_FAVOURITE, icetv.STATE_VISIBLE);
        setItemState(icetv.BUTTON_DEL_FAV, icetv.STATE_VISIBLE);
    } else {
/**
 *      BUTTON_ADD_FAV: YES
 */                
        setItemState(icetv.BUTTON_ADD_FAV, icetv.STATE_VISIBLE);
    }

    if(isRecommended) {
/**
 *      PILL_RECOMMENDED: YES
 */                
        setItemState(icetv.PILL_RECOMMENDED, icetv.STATE_VISIBLE);
    }

    if(recordData) { // Recording
        if(partOfSeries) { // Scheduled series recording
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.3 Series recording, Scheduled     | true/false | [object]   | [object]     | true/false    | true         | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    | 3.3 Series recording, Scheduled     | true/false | [object]   | [object]     | true/false    | true         | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:  (*) Delete Series 
 *                          (*) Delete Episode
 *    PILL_SERIES:          YES
 *    BUTTON_RECORD_ONCE:   DISABLED
 *    BUTTON_UPDATE_SERIES: YES
 */
			/**
			 * Populate Time Popup for a series, ie "Any Time" and then time in 5 min increments
			 */
			this.populateTimeListSeries();

            addDeleteButton( true, "Series scheduled to record on " + seriesRecordData['device_label'], 1, icetv.FUNCTION_REMOVE_SERIES);
            addDeleteButton( true, "Episode scheduled to record on " + recordData['device_label'],      2, icetv.FUNCTION_REMOVE_EPISODE);

            setItemState(icetv.PILL_SERIES,             icetv.STATE_VISIBLE);
            setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
            setItemState(icetv.BUTTON_UPDATE_SERIES,    icetv.STATE_VISIBLE);

            setDeviceForSheetByLabel(icetv.OPTION_SHEET_SERIES, seriesRecordData['device_label']);

			if(seriesRecordData['first_runs_only'] == "0")
				this.changeSeriesRecordType(1);
			else
				this.changeSeriesRecordType(0);

			if(seriesRecordData['network_id'] == "-1")
                this.changeSeriesRecordNetwork(0); // The network list starts at index==1, the first place is "Any Network"
            else {
                var networkIndex = net.indexForID(seriesRecordData['network_id']);
                this.changeSeriesRecordNetwork(networkIndex+1); 
            }

			//start_minutes -1/XX maps to "Any time"/5 minute increments from midnight to midnight -5 mins
			if(seriesRecordData['start_minutes'] == "-1")
				this.changeSeriesRecordTime(0);
			else {
				var timeIndex = timeIndexForMins(seriesRecordData['start_minutes']);
				this.changeSeriesRecordTime(timeIndex);
			}

            this.changeSeriesRecordQuality(seriesRecordData['recording_quality']);

            /**
             * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
             * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
             */
            var recordingsPerDay;
            if(seriesRecordData['recordings_per_day'] == "0")
                recordingsPerDay = 5;
            else {
                recordingsPerDay = seriesRecordData['recordings_per_day'] - 1;
            }
            this.changeSeriesRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL
        
			this.seriesRecordID = seriesRecordData['series_recording_id'];
			this.seriesInfo["series_recording_id"] = seriesRecordData['series_recording_id']
			this.seriesInfo["series_device"] = dv.indexForName(seriesRecordData['device_label']);
            this.seriesInfo["episode_device"] = dv.indexForName(recordData['device_label'])
            
            setItemText(icetv.SERIES_RECORD_LABEL_TYPE,     "record");
            setItemText(icetv.SERIES_RECORD_SHOWTITLE,      epgData['title']);

            setItemState(icetv.BUTTON_SERIES_UPDATE,        icetv.STATE_VISIBLE);
            setItemState(icetv.BUTTON_SERIES_CANCEL,        icetv.STATE_VISIBLE);
            
            DEBUGLOG("SheetManager.js[1167]: Scheduled series recording: Episode Record: No: 1.3/3.3");
        } else { 
            if(isKeyword) { // Keyword recording
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.5 keyword recording               | true/false | [object]   | null         | true/false    | false        | false           | true      | true         | null        | [object] | null        | null/[object]   | null/[object] |
 *    | 3.5 keyword recording               | true/false | [object]   | null         | true/false    | false        | false           | true      | true         | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:      Delete Keyword 
 *                          (*) Delete Episode
 *    PILL_SINGLE:          YES
 *    PILL_KEYWORD_REC:     YES
 *    BUTTON_RECORD_ONCE:   DISABLED
 *    BUTTON_RECORD_SERIES: YES
 */

				/**
				 * Populate Time Popup for a show, ie "Any Time" and then "This Time"
				 */
				this.populateTimeListShow();
				var startHours = parseInt(epgData["time"].substring(11,13), 10);
				var startMins = parseInt(epgData["time"].substring(14,16), 10);
                document.getElementById("epg-sheet-series-record-time-menu").options[1].value = (startHours * 60) + startMins;


                addDeleteButton( false, "Keyword scheduled to record on "+ recordData['device_label'], 1, null);
                addDeleteButton( true, "Episode scheduled to record on " + recordData['device_label'], 2, icetv.FUNCTION_REMOVE_KEYWORD_EPISODE);

                setItemState(icetv.PILL_SINGLE,             icetv.STATE_VISIBLE);
                setItemState(icetv.PILL_KEYWORD_REC,        icetv.STATE_VISIBLE);
                setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_VISIBLE);

                var showRecord = epg.recordForID(recordData['show_id']);
                var flags = (showRecord) ? showRecord['flags'] : null;
                if(flags && (flags & 8))
                    this.changeSeriesRecordType(1);     // First Runs & Reruns
                else
                    this.changeSeriesRecordType(0);     // First Runs

                setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "record");
                setItemText(icetv.SERIES_RECORD_SHOWTITLE,  epgData['title']);

                setItemState(icetv.BUTTON_SERIES_RECORD,    icetv.STATE_VISIBLE);
                setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);

                setItemState(icetv.IWT_COMMENT, icetv.STATE_HIDDEN);

                this.seriesInfo["episode_device"] = dv.indexForName(recordData['device_label'])
                setDeviceForSheetByLabel(icetv.OPTION_SHEET_KEYWORD, recordData['device_label']);
                

                DEBUGLOG("SheetManager.js[1178]: Keyword recording: Single Record: No: 1.5/3.5");
            } else { //Scheduled single recording
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.2 Single recording                | true/false | [object]   | null         | true/false    | false        | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    | 3.2 Single recording                | true/false | [object]   | null         | true/false    | false        | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:          (*) Delete Recording
 *    PILL_SINGLE:                  YES
 *    BUTTON_RECORD_ONCE:           DISABLED
 *    BUTTON_RECORD_SERIES:         YES
 */

				/**
				 * Populate Time Popup for a show, ie "Any Time" and then "This Time"
				 */
				this.populateTimeListShow();
				var startHours = parseInt(epgData["time"].substring(11,13), 10);
				var startMins = parseInt(epgData["time"].substring(14,16), 10);
                document.getElementById("epg-sheet-series-record-time-menu").options[1].value = (startHours * 60) + startMins;

                addDeleteButton( true, "Show scheduled to record on " + recordData['device_label'], 1, icetv.FUNCTION_REMOVE_SHOW);

                setItemState(icetv.PILL_SINGLE,             icetv.STATE_VISIBLE);
                setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_VISIBLE);

                setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "record");
                setItemText(icetv.SERIES_RECORD_SHOWTITLE,  epgData['title']);

                setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);
                setItemState(icetv.BUTTON_SERIES_RECORD,    icetv.STATE_VISIBLE);

                this.seriesInfo["episode_device"] = dv.indexForName(recordData['device_label'])
                setDeviceForSheetByLabel(icetv.OPTION_SHEET_SINGLE, recordData['device_label']);
                
                DEBUGLOG("SheetManager.js[1188]: Scheduled single recording: Episode Record: No: 1.2/3.2");
            }
        }
    } else { // Not a recording, an unscheduled ep of a series, a Scheduled ep or a favourite from a "series page"
        if(partOfSeries) { 
            if(seriesRecordData) { // Scheduled ep from "series page"
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 2.3 Series recording, Scheduled     | true/false | null       | [object]     | true/false    | true         | false           | false     | false        | null        | null     | [object]    | null/[object]   | null/[object] |
 *    | 4.3 Series recording, Scheduled     | true/false | null       | [object]     | true/false    | true         | false           | false     | false        | null        | null     | null        | null/[object]   | null/[object] |
 *    | 5.3 Series recording, Scheduled     | true/false | null       | [object]     | true          | true         | false           | false     | false        | null        | null     | null        | [object]        | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:          (*) Delete Series
 *    PILL_SERIES:                  YES
 *    BUTTON_RECORD_ONCE:           DISABLED
 *    BUTTON_UPDATE_SERIES:         YES
 *    SHEET_SERIES_RECORD_OPTIONS:  YES
 */
				/**
				 * Populate Time Popup for a series, ie "Any Time" and then time in 5 min increments
				 */
				this.populateTimeListSeries();

                addDeleteButton( true, "Series scheduled to record on " + seriesRecordData['device_label'], 1, icetv.FUNCTION_REMOVE_SERIES);

                setItemState(icetv.PILL_SERIES,             icetv.STATE_VISIBLE);
                if(isFav)
                    setItemState(icetv.PILL_FAVOURITE,      icetv.STATE_VISIBLE);
                    
                setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                setItemState(icetv.BUTTON_UPDATE_SERIES,    icetv.STATE_VISIBLE);

                setItemText(icetv.SERIES_RECORD_LABEL_TYPE,     "update");
                setItemText(icetv.SERIES_RECORD_SHOWTITLE,      seriesRecordData['series_name']);

                if(seriesRecordData['first_runs_only'] == "0")
                    this.changeSeriesRecordType(1);
                else
                    this.changeSeriesRecordType(0);

                if(seriesRecordData['network_id'] == "-1")
                    this.changeSeriesRecordNetwork(0); // The network list starts at index==1, the first place is "Any Network"
                else {
                    var networkIndex = net.indexForID(seriesRecordData['network_id']);
                    this.changeSeriesRecordNetwork(networkIndex+1); 
                }

                //start_minutes -1/XX maps to "Any time"/5 minute increments from midnight to midnight -5 mins
                if(seriesRecordData['start_minutes'] == "-1")
                    this.changeSeriesRecordTime(0);
                else {
                    var timeIndex = timeIndexForMins(seriesRecordData['start_minutes']);
                    this.changeSeriesRecordTime(timeIndex);
                }

                this.changeSeriesRecordQuality(seriesRecordData['recording_quality']);

                /**
                 * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
                 * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
                 */
                var recordingsPerDay;
                if(seriesRecordData['recordings_per_day'] == "0")
                    recordingsPerDay = 5;
                else {
                    recordingsPerDay = seriesRecordData['recordings_per_day'] - 1;
                }
                this.changeSeriesRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL
            
                this.seriesRecordID = seriesRecordData['series_recording_id'];
                this.seriesInfo["series_recording_id"] = seriesRecordData['series_recording_id']
                this.seriesInfo["series_device"] = dv.indexForName(seriesRecordData['device_label']);
                setDeviceForSheetByLabel(icetv.OPTION_SHEET_SERIES, seriesRecordData['device_label']);

                setItemState(icetv.BUTTON_SERIES_UPDATE,    icetv.STATE_VISIBLE);
                setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);
                setItemClass(icetv.SHEET_SERIES_CONTAINER,  "sheet-record-series-series");

                DEBUGLOG("SheetManager.js[1203]: Scheduled Series recording (series page): Episode Record: No: 2.3/4.3/5.3");
            } else { // Unscheduled Ep of series
                if(epgData) {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.4 Series recording, Not scheduled | true/false | null       | null         | true/false    | true         | true            | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:    (*) Delete Series
 *    PILL_SERIES_CANCEL:     YES
 *    BUTTON_RECORD_ONCE:     YES
 *    BUTTON_UPDATE_SERIES:   YES
 */
                    var series_id = epgData['series_id'];
                    var seriesRecordData = mgs.recordForID(series_id);
                                    
					/**
					 * Populate Time Popup for a series, ie "Any Time" and then time in 5 min increments
					 */
					this.populateTimeListSeries();

                    addDeleteButton( true, "Series scheduled to record on " + seriesRecordData['device_label'], 1, null);

                    setItemState(icetv.PILL_SERIES_CANCEL,      icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_UPDATE_SERIES,    icetv.STATE_VISIBLE);

                    setItemText(icetv.SINGLE_RECORD_LABEL_TYPE, "record");
                    setItemText(icetv.SINGLE_RECORD_SHOWTITLE,  epgData['title']);

                    setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "update");
                    setItemText(icetv.SERIES_RECORD_SHOWTITLE,  epgData['title']);

                    setDeviceForSheetByLabel(icetv.OPTION_SHEET_SERIES, seriesRecordData['device_label']);

                    if(seriesRecordData['first_runs_only'] == "0")
                        this.changeSeriesRecordType(1);
                    else
                        this.changeSeriesRecordType(0);

                    if(seriesRecordData['network_id'] == "-1")
                        this.changeSeriesRecordNetwork(0); // The network list starts at index==1, the first place is "Any Network"
                    else {
                        var networkIndex = net.indexForID(seriesRecordData['network_id']);
                        this.changeSeriesRecordNetwork(networkIndex+1); 
                    }

					//start_minutes -1/XX maps to "Any time"/5 minute increments from midnight to midnight -5 mins
					if(seriesRecordData['start_minutes'] == "-1")
						this.changeSeriesRecordTime(0);
					else {
						var timeIndex = timeIndexForMins(seriesRecordData['start_minutes']);
						this.changeSeriesRecordTime(timeIndex);
					}

                    this.changeSeriesRecordQuality(seriesRecordData['recording_quality']);

                    /**
                     * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
                     * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
                     */
                    var recordingsPerDay;
                    if(seriesRecordData['recordings_per_day'] == "0")
                        recordingsPerDay = 5;
                    else {
                        recordingsPerDay = seriesRecordData['recordings_per_day'] - 1;
                    }
                    this.changeSeriesRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL
                
                    this.seriesRecordID = seriesRecordData['series_recording_id'];
                    this.seriesInfo["series_recording_id"] = seriesRecordData['series_recording_id']
                    this.seriesInfo["series_device"] = dv.indexForName(seriesRecordData['device_label']);
                    this.seriesInfo["episode_device"] = dv.indexForName(seriesRecordData['device_label'])

                    setButtonFunction( icetv.BUTTON_SINGLE_RECORD, icetv.FUNCTION_RECORD_EPISODE );

                    setItemState(icetv.BUTTON_SINGLE_RECORD,    icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SINGLE_CANCEL,    icetv.STATE_VISIBLE);

                    setItemState(icetv.BUTTON_SERIES_UPDATE,    icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);
//                    setItemClass(icetv.SHEET_SERIES_CONTAINER,  "sheet-record-series-series");

                    DEBUGLOG("SheetManager.js[1212]: Unscheduled Series recording: Episode Record: Yes: 1.4");
                } else {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 4.1 Not a recording                 | true       | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | [object]      | 
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    PILL_FAVOURITE:               YES
 *    BUTTON_RECORD_ONCE:           DISABLED
 *    BUTTON_RECORD_SERIES:         YES
 *    SHEET_SERIES_RECORD_OPTIONS:  YES
 */

                    this.populateTimeListSeries();

                    setItemState(icetv.PILL_FAVOURITE,          icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                    setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_VISIBLE);

                    setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "record");
                    setItemText(icetv.SERIES_RECORD_SHOWTITLE,  favData['series_name']);

                    setItemState(icetv.BUTTON_SERIES_RECORD,    icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);
                    setItemClass(icetv.SHEET_SERIES_CONTAINER,  "sheet-record-series-series");

                    DEBUGLOG("SheetManager.js[1212]: Unscheduled Favourite: 4.1");
                }
            }
        } else { 
            if(isKeyword) { // keyword
                if(viewOrRecord) {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 4.5 keyword recording               | true/false | null       | null         | true/false    | false        | false           | true      | true         | [object]    | null     | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:    (*) Delete Keyword
 *    PILL_KEYWORD_REC:       YES
 *    BUTTON_ADD_FAV:         HIDDEN
 *    BUTTON_RECORD_ONCE:     DISABLED
 *    BUTTON_UPDATE_KEYWORD:  YES
 */
                    if(keywordData["keyword_recording_id"] != "0")
                        addDeleteButton( true, "Keyword scheduled to record on " + keywordData['device_label'], 1, icetv.FUNCTION_REMOVE_KEYWORD);

                    setItemState(icetv.PILL_KEYWORD_REC,            icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_ADD_FAV,              icetv.STATE_DISABLED);
                    setItemState(icetv.BUTTON_RECORD_ONCE,          icetv.STATE_DISABLED);

                    if(keywordData["keyword_recording_id"] == "0")
                        setItemState(icetv.BUTTON_CREATE_KEYWORD,       icetv.STATE_VISIBLE);
                    else
                        setItemState(icetv.BUTTON_UPDATE_KEYWORD,       icetv.STATE_VISIBLE);

                    var pattern = keywordData["match_pattern"];
                    if(keywordData["avoid_pattern"]){
                        var avoidArray = smartSplit( " ", keywordData["avoid_pattern"], false, '"', false);
                        pattern += " -" + avoidArray.join(" -");
                    }

					if(keywordData)
						setDeviceForSheetByLabel(icetv.OPTION_SHEET_KEYWORD, keywordData['device_label']);

                    if(keywordData["keyword_recording_id"] == "0")
         				setItemText(icetv.KEYWORD_RECORD_LABEL_TYPE, "Create a Keyword Rec/Fav for");
                    else {
						if(keywordData["view_or_record"] == "0")
	         				setItemText(icetv.KEYWORD_RECORD_LABEL_TYPE, "Update the Keyword Fav for");
						else
	         				setItemText(icetv.KEYWORD_RECORD_LABEL_TYPE, "Update the Keyword Rec for");;
					}

                    setItemText(icetv.KEYWORD_RECORD_SHOWTITLE,     pattern);
                    setInputText(icetv.OPTION_KEYWORD_PATTERN,      pattern);

                    this.keywordRecordPattern = pattern;

                    // view_or_record 0/1 maps to "Favourite"/"Record" which are indexes 0/1
                    if(keywordData['view_or_record'] == "0") {
                        this.changeKeywordRecordAction(1);
                    } else {
                        this.changeKeywordRecordAction(0);
                    }

                    // first_runs_only 0/1 maps to "First runs"/"First & reruns" which are indexes 0/1
                    if(keywordData['first_runs_only'] == "0")
                        this.changeKeywordRecordType(1);
                    else
                        this.changeKeywordRecordType(0);

					if(keywordData['network_id'] == "-1")
		                this.changeSeriesRecordNetwork(0); // The network list starts at index==1, the first place is "Any Network"
		            else {
		                var networkIndex = net.indexForID(keywordData['network_id']);
		                this.changeKeywordRecordNetwork(networkIndex+1); 
		            }
                
                    this.changeKeywordRecordQuality(keywordData['recording_quality']);

                    /**
                     * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
                     * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
                     */
                    var recordingsPerDay;
                    if(keywordData['recordings_per_day'] == "0")
                        recordingsPerDay = 5;
                    else {
                        recordingsPerDay = keywordData['recordings_per_day'] - 1;
                    }
                    this.changeKeywordRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL

                    if(keywordData["keyword_recording_id"] == "0")
                        setItemState(icetv.BUTTON_KEYWORD_RECORD,       icetv.STATE_VISIBLE);
                    else 
                        setItemState(icetv.BUTTON_KEYWORD_UPDATE,       icetv.STATE_VISIBLE);

                    setItemState(icetv.BUTTON_KEYWORD_CANCEL,       icetv.STATE_VISIBLE);
                    setItemState(icetv.IWT_COMMENT,                 icetv.STATE_HIDDEN);
                    setDeviceForSheetByLabel(icetv.OPTION_SHEET_KEYWORD, keywordData['device_label']);
                    
                    DEBUGLOG("SheetManager.js[1224]: Keyword recording: Single Record: No: 4.5");
                } else {
                    if(canRecordSingle) {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | true            | true      | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    | 3.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | true            | true      | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    PILL_KEYWORD_FAV:       YES
 *    BUTTON_ADD_FAV:         HIDDEN
 *    BUTTON_RECORD_ONCE:     YES
 *    BUTTON_RECORD_SERIES:   YES
 */

						this.populateTimeListSeries();

                        setItemState(icetv.PILL_KEYWORD_FAV,            icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_ADD_FAV,              icetv.STATE_DISABLED);
                        setItemState(icetv.BUTTON_RECORD_ONCE,          icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_RECORD_SERIES,        icetv.STATE_VISIBLE);

                        setItemText(icetv.SINGLE_RECORD_LABEL_TYPE,     "record");
                        setItemText(icetv.SINGLE_RECORD_SHOWTITLE,      epgData['title']);

                        setItemText(icetv.SERIES_RECORD_LABEL_TYPE,     "record");
                        setItemText(icetv.SERIES_RECORD_SHOWTITLE,      epgData['title']);

                        setItemState(icetv.BUTTON_SINGLE_RECORD,        icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_SINGLE_CANCEL,        icetv.STATE_VISIBLE);

                        setItemState(icetv.BUTTON_SERIES_UPDATE,        icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_SERIES_CANCEL,        icetv.STATE_VISIBLE);

                        setButtonFunction( icetv.BUTTON_SINGLE_RECORD,  icetv.FUNCTION_RECORD_SHOW );
                        setItemState(icetv.IWT_COMMENT,                 icetv.STATE_HIDDEN);

                        DEBUGLOG("SheetManager.js[1235]: Keyword favourite: Single Record: Yes: 1.6/3.6");
                    } else {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 4.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | false           | true      | false        | [object]    | null     | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    SHOW_DELETE_BUTTONS:    (*) Delete Keyword
 *    PILL_KEYWORD_FAV:       YES
 *    BUTTON_ADD_FAV:         HIDDEN
 *    BUTTON_RECORD_ONCE:     DISABLED
 *    BUTTON_UPDATE_KEYWORD:  YES
 */
                        addDeleteButton( true, "Delete keyword favourite", 1, icetv.FUNCTION_REMOVE_KEYWORD);

                        setItemState(icetv.PILL_KEYWORD_FAV,        icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_ADD_FAV,          icetv.STATE_DISABLED);
                        setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                        setItemState(icetv.BUTTON_UPDATE_KEYWORD,   icetv.STATE_VISIBLE);

                        if(keywordData)
                            setDeviceForSheetByLabel(icetv.OPTION_SHEET_KEYWORD, keywordData['device_label']);

                        var pattern = keywordData["match_pattern"];
                        if(keywordData["avoid_pattern"]){
                            var avoidArray = smartSplit( " ", keywordData["avoid_pattern"], false, '"', false);
                            pattern += " -" + avoidArray.join(" -");
                        }

                        setItemText(icetv.KEYWORD_RECORD_LABEL_TYPE,    "Update the Keyword Fav for");
                        setItemText(icetv.KEYWORD_RECORD_SHOWTITLE,     pattern);
                        setInputText(icetv.OPTION_KEYWORD_PATTERN,      pattern);
    
                        this.keywordRecordPattern = pattern;

                        // view_or_record 0/1 maps to "Favourite"/"Record" which are indexes 0/1
                        if(keywordData['view_or_record'] == "0") {
                            this.changeKeywordRecordAction(1);
                        } else {
                            this.changeKeywordRecordAction(0);
                        }

                        // first_runs_only 0/1 maps to "First runs"/"First & reruns" which are indexes 0/1
                        if(keywordData['first_runs_only'] == "0")
                            this.changeKeywordRecordType(1);
                        else
                            this.changeKeywordRecordType(0);

                        if(keywordData['network_id'] == "-1")
                            this.changeSeriesRecordNetwork(0); // The network list starts at index==1, the first place is "Any Network"
                        else {
                            var networkIndex = net.indexForID(keywordData['network_id']);
                            this.changeKeywordRecordNetwork(networkIndex+1); 
                        }
                    
                        this.changeKeywordRecordQuality(keywordData['recording_quality']);

                        /**
                         * The Recordings Per Day select list is numbered 0 = 1 .. 5 = ALL, but the
                         * table in the DB has 0 = ALL, 1 = 1 .. 5 = 5 
                         */
                        var recordingsPerDay;
                        if(keywordData['recordings_per_day'] == "0")
                            recordingsPerDay = 5;
                        else {
                            recordingsPerDay = keywordData['recordings_per_day'] - 1;
                        }
                        this.changeKeywordRecordLimit(recordingsPerDay); // "0" - ALL, "1" = 1 etc, but the select list has idx 0 = 1 ... idx 5 = ALL

                        setItemState(icetv.BUTTON_KEYWORD_UPDATE,   icetv.STATE_VISIBLE);
                        setItemState(icetv.BUTTON_KEYWORD_CANCEL,   icetv.STATE_VISIBLE);
                        setItemState(icetv.IWT_COMMENT,             icetv.STATE_HIDDEN);

                        DEBUGLOG("SheetManager.js[1244]: Keyword favourite (series page): Single Record: No: 4.6");
                    }
                }
            } else { // Not a recording
                if(canRecordSingle) {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 1.1 Not a recording                 | true/false | null       | null         | true/false    | false        | true            | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    BUTTON_RECORD_ONCE: YES
 *    BUTTON_RECORD_SERIES: YES
 */
					/**
					 * Populate Time Popup for a show, ie "Any Time" and then "This Time"
					 */
					this.populateTimeListShow();
					var startHours = parseInt(epgData["time"].substring(11,13), 10);
					var startMins = parseInt(epgData["time"].substring(14,16), 10);
                    document.getElementById("epg-sheet-series-record-time-menu").options[1].value = (startHours * 60) + startMins;

                    setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_VISIBLE);


                    setItemText(icetv.SINGLE_RECORD_LABEL_TYPE, "record");
                    setItemText(icetv.SINGLE_RECORD_SHOWTITLE,  epgData['title']);

                    setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "record");
                    setItemText(icetv.SERIES_RECORD_SHOWTITLE,  epgData['title']);

                    var flags = epgData['flags'];
                    if(flags && (flags & 8))
                        this.changeSeriesRecordType(1);     // First Runs & Reruns
                    else
                        this.changeSeriesRecordType(0);     // First Runs


                    setItemState(icetv.BUTTON_SINGLE_RECORD,        icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SINGLE_CANCEL,        icetv.STATE_VISIBLE);

                    setItemState(icetv.BUTTON_SERIES_RECORD,        icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SERIES_CANCEL,        icetv.STATE_VISIBLE);

                    setButtonFunction( icetv.BUTTON_SINGLE_RECORD,  icetv.FUNCTION_RECORD_SHOW );

                    DEBUGLOG("SheetManager.js[1256]: Not a recording: Single Record: Yes: 1.1");
                } else {
/**
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *    | 2.1 Not a recording                 | true/false | null       | null         | true/false    | false        | false           | false     | false        | null        | null     | [object]    | null/[object]   | null/[object] |
 *    | 5.1 Not a recording                 | true/false | null       | null         | true          | false        | false           | false     | false        | null        | null     | null        | [object]        | null/[object] |
 *    +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
 *
 *    BUTTON_RECORD_ONCE: DISABLED
 *    BUTTON_RECORD_SERIES: YES
 */
					this.populateTimeListSeries();

                    setItemState(icetv.BUTTON_RECORD_ONCE,      icetv.STATE_DISABLED);
                    setItemState(icetv.BUTTON_RECORD_SERIES,    icetv.STATE_VISIBLE);

                    setItemText(icetv.SERIES_RECORD_LABEL_TYPE, "record");

                    if(popularData)
                        setItemText(icetv.SERIES_RECORD_SHOWTITLE,  popularData["series_name"]);
                    else if(recommendedData)
                        setItemText(icetv.SERIES_RECORD_SHOWTITLE,  recommendedData["series_name"]);

                    setItemState(icetv.BUTTON_SERIES_RECORD,    icetv.STATE_VISIBLE);
                    setItemState(icetv.BUTTON_SERIES_CANCEL,    icetv.STATE_VISIBLE);

                    DEBUGLOG("SheetManager.js[1266]: Not a recording (series page): Single Record: No: 2.1/5.1");
                }
            }
        }
    }

    DEBUGLOG("SheetManager.js[1487]: ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////");

    setItemState(icetv.SHEET_BUTTONS, icetv.STATE_VISIBLE);

    prepareSheetForDisplay();
    
	var container;
	if(selectedPage == 0)
        setItemOpacity(icetv.EPG_CONTAINER, 0.4);
	else if(selectedPage == 1)
        setItemOpacity(icetv.POPULAR_CONTAINER, 0.4);
	else if(selectedPage == 2)
        setItemOpacity(icetv.UPCOMING_CONTAINER, 0.4);
	else if(selectedPage == 3)
        setItemOpacity(icetv.SERIES_CONTAINER, 0.4);
	else if(selectedPage == 4)
        setItemOpacity(icetv.RECOMMENDED_CONTAINER, 0.4);
	
	this.showSheet(0);

//    DEBUGLOG("SheetManager.js[2193]: epg-sheet: " + document.getElementById("epg-sheet").innerHTML);
}

SheetManager.prototype.fillEpgSheetDetails = function(id, mode, updateonly, isSeriesId) {
    DEBUGLOG("SheetManager.js[1164]: fillEpgSheetDetails(" + id + ", " + mode + ", " + updateonly + ", " + isSeriesId + ")"); 
    /**
     * The mode can take on one of four values
     * 1 - show_id - Used in EPG & "My Upcoming Shows"
     * 2 - series_id - Used on "Most Popular"
     * 3 - series_id - Used on "My Shows"
     * 4 - series_id - Used on "Recommended"
     * 5 - keyword_recording_id - Used on "My Shows" for a keyword recording
     */


/**
  +-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------+-------------+-----------------+---------------+
  | 1 TV GUIDE                                                                                                                                                                                                                        |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 1.1 Not a recording                 | true/false | null       | null         | true/false    | false        | true            | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 1.2 Single recording                | true/false | [object]   | null         | true/false    | false        | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 1.3 Series recording, Scheduled     | true/false | [object]   | [object]     | true/false    | true         | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 1.4 Series recording, Not scheduled | true/false | null       | null         | true/false    | true         | true            | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 1.5 keyword recording               | true/false | [object]   | null         | true/false    | false        | false           | true      | true         | null        | [object] | null        | null/[object]   | null/[object] |
  | 1.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | true            | true      | false        | null        | [object] | null        | null/[object]   | null/[object] |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 3 UPCOMING SHOWS                                                                                                                                                                                                                  |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 3.1 Not a recording                 | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 3.2 Single recording                | true/false | [object]   | null         | true/false    | false        | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 3.3 Series recording, Scheduled     | true/false | [object]   | [object]     | true/false    | true         | false           | false     | false        | null        | [object] | null        | null/[object]   | null/[object] |
  | 3.4 Series recording, Not scheduled | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 3.5 keyword recording               | true/false | [object]   | null         | true/false    | false        | false           | true      | true         | null        | [object] | null        | null/[object]   | null/[object] |
  | 3.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | true            | true      | false        | null        | [object] | null        | null/[object]   | null/[object] |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
*/
	if(mode == 1){ // show_id, EPG or "My Upcoming Shows"
		var epgData = epg.recordForID(id)
		if(!epgData)
			return;
		
		var seriesRecord = mgs.recordForID(epgData["series_id"]);
		var singleRecord = mgu.recordForShowID(epgData["id"]);
   		var favRecord = fav.recordForID(id);

		this.seriesID = epgData["series_id"];
		this.showID = epgData["id"];

		document.getElementById("epg-sheet-show-name").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + epgData['series_id'] + "')");
        
		document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + epgData['series_id'] + "')");
		
		this.seriesInfo["network_id"] = epgData["network_id"];
		this.seriesInfo["time"] = epgData['time'].substring(11)
		
		var title = epgData["title"];
		var year = epgData["year"];
		var description = epgData["description"];

        if(epgData["director"])
            description = description + " Directed by " + epgData["director"] + ".";
            
        if(epgData["actors"])
            description = description + " " + epgData["actors"] + ".";
        
		var subtitle = null;
		if(epgData["subtitle"])
			subtitle = epgData["subtitle"];

		var showdate = new Date(epgData['time'].substring(0,4), parseInt(epgData['time'].substring(5,7), 10)-1, epgData['time'].substring(8,10), 
			epgData['time'].substring(11,13), epgData['time'].substring(14,16), epgData['time'].substring(17,19)
		);

		var monthNames = Array('January','February','March','April','May','June','July','August','September','October','November','December');
		var dayNames = Array('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday');
		
		var time;
		if(epg.timeFormat == 24){
			var minutes = showdate.getMinutes();
			if(minutes < 10)
				minutes = "0" + minutes;
				
			var hours = showdate.getHours();
			if(hours < 10)
				hours = "0" + hours;

			time = hours + ':' + minutes + ", " + dayNames[showdate.getDay()] + ", " + showdate.getDate() + " " + monthNames[showdate.getMonth()] + " " + showdate.getFullYear();
		} else {
			if(showdate.getHours() >= 12)
				suffix = "pm"
			else
				suffix = "am"
			
			var hours = showdate.getHours();
			if(hours == 0)
				hours = 12;
			else if(hours > 12)
				hours -= 12;

			var minutes = showdate.getMinutes();
			if(minutes < 10)
				minutes = "0" + minutes;
			time = hours + ':' + minutes + suffix + ", " + dayNames[showdate.getDay()] + ", " + showdate.getDate() + " " + monthNames[showdate.getMonth()] + " " + showdate.getFullYear();
		}
		
		var additional = epgData['duration'] + " minutes, " + decodeRating(epgData['rating']);
		if(epgData['category_name'])
			additional += ", " + epgData['category_name'];
			
		var showFlags = decodeFlags(epgData['flags']);
		var showFlagsLength = showFlags.length;
		for(var i=0;i<showFlagsLength;i++)
			additional += ", " + showFlags[i];


		var recordData          = null;
		var seriesRecordData    = null;
		var keywordData         = null;
		var isFavorite          = false;
		var isRecommended       = false;
		var partOfSeries        = false;
        var isKeyword           = false;
        var viewOrRecord        = false;
        var canRecordSingle     = false;
        var popularData         = null;
        var recommendedData     = null;
        var favData             = null;
		
		if(epgData['part_of_series'] == "1")
			partOfSeries = true;

		if(epgData['is_scheduled'] == "1"){
			if(epgData['part_of_series'] == "1"){
				if(seriesRecord){
					seriesRecordData = seriesRecord;
					this.seriesRecordID = seriesRecord['series_recording_id'];
				}
			}
			
			if(singleRecord)
				recordData = singleRecord;
		}
		
		if(epgData['is_favorite'] == "1") {
			isFavorite = true;
            favData = favRecord;
        }
		
		if(isRecommendedYWE(epgData["series_id"]) == "1")
			isRecommended = true;
		if(recordData || seriesRecordData || isFavorite)
			isRecommended = false;

        if(singleRecord){
            isKeyword = (singleRecord['is_keyword'] == "1");
            viewOrRecord = (singleRecord['view_or_record'] == "1");
        }
					
        if(!recordData)
            canRecordSingle = true;
                                
		this.setSeriesOptionsMode(0);
        var networkIndex = net.indexForID(epgData['network_id']);
		this.changeSeriesRecordNetwork(networkIndex+1); // The network list starts at index==1, the first place is "Any Network"
		this.fillEpgSheetDetailsSecondary(updateonly, title, subtitle, year, time, additional, description, isFavorite, recordData, seriesRecordData, isRecommended, partOfSeries, canRecordSingle, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData)
	}

/*
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 2 MOST POPULAR                                                                                                                                                                                                                    |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 2.1 Not a recording                 | true/false | null       | null         | true/false    | false        | false           | false     | false        | null        | null     | [object]    | null/[object]   | null/[object] |
  | 2.2 Single recording                | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           |
  | 2.3 Series recording, Scheduled     | true/false | null       | [object]     | true/false    | true         | false           | false     | false        | null        | null     | [object]    | null/[object]   | null/[object] |
  | 2.4 Series recording, Not scheduled | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           |
  | 2.5 keyword recording               | true/false | null       | null         | true/false    | false        | false           | true      | true         | [object]    | null     | null        | null/[object]   | null/[object] |
  | 2.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | false           | true      | false        | [object]    | null     | null        | null/[object]   | null/[object] |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
*/
	if(mode == 2){ // series_id - Used on "Most Popular"
		this.seriesID = id;
		this.showID = 0;

		var record = popular.recordForID(id);
                
		if(!record)
			return;
		
		document.getElementById("epg-sheet-show-name").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + record['series_id'] + "')");
		document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + record['series_id'] + "')");

		var seriesRecord = mgs.recordForID(id);
		var favRecord = fav.recordForID(id);

		var title               = record["series_name"];
		var year                = record["year"];
		var description         = record["series_description"];
		var additional          = null;
		var time                = null;
		var subtitle            = null;

		var recordData          = null;
		var seriesRecordData    = null;
		var keywordData         = null;
        var epgData             = null;
		var partOfSeries        = false;
		var isFavorite          = false;
		var isRecommended       = false;
        var isKeyword           = false;
        var viewOrRecord        = false;
        var popularData         = record;
        var recommendedData     = null;
        var favData             = null;

		if(seriesRecord) {
			seriesRecordData = seriesRecord
            partOfSeries = true;
        }
						
		if(favRecord) {
			isFavorite = true;
            favData = favRecord;
        }
		
		if(isRecommendedYWE(record["series_id"]) == "1")
			isRecommended = true;
		if(favRecord || seriesRecordData)
			isRecommended = false;
	
		this.setSeriesOptionsMode(0);
		this.changeSeriesRecordNetwork(0);
		this.fillEpgSheetDetailsSecondary(updateonly, title, subtitle, year, time, additional, description, isFavorite, recordData, seriesRecordData, isRecommended, partOfSeries, false, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData)
	}

/*
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 4 MY SHOWS                                                                                                                                                                                                                        |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 4.1 Not a recording                 | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.2 Single recording                | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.3 Series recording, Scheduled     | true/false | null       | [object]     | true/false    | true         | false           | false     | false        | null        | null     | null        | null/[object]   | null/[object] |
  | 4.4 Series recording, Not scheduled | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.5 keyword recording               | true/false | null       | null         | true/false    | false        | false           | true      | true         | [object]    | null     | null        | null/[object]   | null/[object] |
  | 4.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | false           | true      | false        | [object]    | null     | null        | null/[object]   | null/[object] |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+

    NOTE: 4.5 & 4.6 are handled in mode 5
*/
	if(mode == 3){ // isSeriesId => series_id else series_recording_id
		this.showID = 0;
		var favRecord;
		var seriesRecord;
        if(isSeriesId) {
            seriesRecord = mgs.recordForID(id);
            this.seriesID = id;
        } else {
            favRecord = fav.recordForID(id);
			if(favRecord) {
            	seriesRecord = mgs.recordForID(id);
				this.seriesID = id;
			}
			else {
	            seriesRecord = mgs.recordForSeriesRecordingID(id);
	            this.seriesID = seriesRecord["series_id"];
			}
        }
        
        if(seriesRecord) {
            favRecord = fav.recordForID(seriesRecord["series_id"]);
			this.seriesID = seriesRecord["series_id"];
        } else {
            favRecord = fav.recordForID(id);
			this.seriesID = id;
		}
        
		if(!seriesRecord && !favRecord)
			return;


		var title;
		var description;
		var year;
		var isRecommended = false;
        var networkIndex;

		if(seriesRecord){
            document.getElementById("epg-sheet-show-name").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + seriesRecord['series_id'] + "')");
            document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + seriesRecord['series_id'] + "')");

			title = seriesRecord["series_name"];
			year = seriesRecord["year"];
			description = seriesRecord["series_description"];
            networkIndex = net.indexForID(seriesRecord["network_id"]);
			if(isRecommendedYWE(seriesRecord["series_id"]) == "1")
				isRecommended = true;
		} else {
            document.getElementById("epg-sheet-show-name").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + favRecord['series_id'] + "')");
            document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + favRecord['series_id'] + "')");

			title = favRecord["series_name"];
			year = favRecord["year"];
			description = favRecord["series_description"];
            networkIndex = -1; // There is no network associated with a Fav
			if(isRecommendedYWE(favRecord["series_id"]) == "1")
				isRecommended = true;
		}

		var additional          = null;
		var time                = null;
		var recordData          = null;
		var subtitle            = null;
		var keywordData         = null;
        var epgData             = null;
		var partOfSeries        = true;
        var isKeyword           = false;
        var viewOrRecord        = false;
        var popularData         = null;
        var recommendedData     = null;
        var favData             = null;
		var seriesRecordData    = null;
		var isFavorite          = false;

		if(seriesRecord)
			seriesRecordData = seriesRecord
			
		if(favRecord) {
			isFavorite = true;
            favData = favRecord;
        }
	
		this.setSeriesOptionsMode(0);
		this.changeSeriesRecordNetwork(networkIndex+1); // The network list starts at index==1, the first place is "Any Network"
		this.fillEpgSheetDetailsSecondary(updateonly, title, subtitle, year, time, additional, description, isFavorite, recordData, seriesRecordData, isRecommended, partOfSeries, false, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData)
	}

/*
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 5 RECOMMENDED                                                                                                                                                                                                                     |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 5.1 Not a recording                 | true/false | null       | null         | true          | false        | false           | false     | false        | null        | null     | null        | [object]        | null/[object] |
  | 5.2 Single recording                | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           |
  | 5.3 Series recording, Scheduled     | true/false | null       | [object]     | true          | true         | false           | false     | false        | null        | null     | null        | [object]        | null/[object] |
  | 5.4 Series recording, Not scheduled | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 5.5 keyword recording               | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 5.6 Keyword favourite               | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
*/
	if(mode == 4){
		this.seriesID = id;
		this.showID = 0;
		var record = rcm.recordForID(id);
		if(!record)
			return;
			
		document.getElementById("epg-sheet-show-name").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + record['series_id'] + "')");
		document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('http://www.icetv.com.au/interactive/show/" + record['series_id'] + "')");

		var seriesRecord = mgs.recordForID(id);
		var favRecord = fav.recordForID(id);

		var title               = record["series_name"];
		var description         = record["series_description"];
		var year                = record["year"];
		var additional          = null;
		var time                = null;
		var subtitle            = null

        document.getElementById("series_record_label_type").innerText = "record";
        document.getElementById("epg-sheet-series-record-showtitle").innerText = title;
		
		var partOfSeries        = false;
		var isRecommended       = true;
		var isFavorite          = false;
		var isKeyword           = false;
		var viewOrRecord        = false;
        var canRecordSingle     = false;
		var recordData          = null;
		var seriesRecordData    = null;
        var keywordData         = null;
        var epgData             = null;
        var popularData         = null;
        var recommendedData     = record;
        var favData             = null;
			
        if(seriesRecord)
            partOfSeries = true;
            
		if(favRecord) {
			isFavorite = true;
            favData = favRecord;
        }

		this.changeSeriesRecordTime(0);
		this.changeSeriesRecordNetwork(0);
		this.changeSeriesRecordType(0);
		if(this.seriesDeviceControllers.length > 0)
			this.changeSeriesRecordDevice(0);
	
		this.setSeriesOptionsMode(0);
		this.fillEpgSheetDetailsSecondary(updateonly, title, subtitle, year, time, additional, description, isFavorite, recordData, seriesRecord, isRecommended, partOfSeries, canRecordSingle, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData)
	}
    
/*
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 4 MY SHOWS                                                                                                                                                                                                                        |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | CASE                                | isFavorite | recordData | seriesRecord | isRecommended | partOfSeries | canRecordSingle | isKeyword | viewOrRecord | keywordData | epgData  | popularData | recommendedData | favData       |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+
  | 4.1 Not a recording                 | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.2 Single recording                | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.3 Series recording, Scheduled     | true/false | null       | [object]     | true/false    | true         | false           | false     | false        | null        | null     | null        | null/[object]   | null/[object] |
  | 4.4 Series recording, Not scheduled | ---        | ---        | ---          | ---           | ---          | ---             | ---       | ---          | ---         | ---      | ---         | ---             | ---           | 
  | 4.5 keyword recording               | true/false | null       | null         | true/false    | false        | false           | true      | true         | [object]    | null     | null        | null/[object]   | null/[object] |
  | 4.6 Keyword favourite               | true/false | null       | null         | true/false    | false        | false           | true      | false        | [object]    | null     | null        | null/[object]   | null/[object] |
  +-------------------------------------+------------+------------+--------------+---------------+--------------+-----------------+-----------+--------------+-------------+----------+-------------+-----------------+---------------+

    NOTE: 4.1-4.4 are handled in mode 3
*/
   	if(mode == 5){
        DEBUGLOG("SheetManager.js[1409]: mode: 5");

        var title               = null;
        var year                = null;
        var description         = null;
        var subtitle            = null;
        var time                = null;
        var additional          = null;
        var recordData          = null;
        var seriesRecordData    = null;
        var epgData             = null;
        var isFavorite          = false;
        var isRecommended       = false;
        var partOfSeries        = false;
        var isKeyword           = false;
        var viewOrRecord        = false;
        var canRecordSingle     = false;
        var popularData         = null;
        var recommendedData     = null;
        var favData             = null;
        
        if(id != 0) {
            var keywordData = key.recordForID(id)
            if(!keywordData)
                return;
            
            this.keywordData = keywordData;
            this.keywordRecordingID = keywordData["keyword_recording_id"];
                
            title = "'" + keywordData["match_pattern"];
            if(keywordData["avoid_pattern"]){
                var avoidArray = smartSplit( " ", keywordData["avoid_pattern"], false, '"', false);
                title += " -" + avoidArray.join(" -");
            }
            title += "'";
        } else {
        
            /**
             * Split search string into match and avoid patterns
             */
            var keywordRecordPattern = document.getElementById("epg-controls-search").value;
            var matchPattern;
            var tokenArray = smartSplit( " ", keywordRecordPattern, false, "\"", false );
            var idx=0;
            var numTokens = tokenArray.length;
            for(idx=0; idx<numTokens; idx++) {
                if(matchPattern != null)
                    matchPattern += " ";
                else
                    matchPattern = "";
                matchPattern += tokenArray[idx];
            }
    
            /**
             * give the pattern safe defaults if they are not needed.
             */
            if(matchPattern == null)
                matchPattern = "";

            var keywordData = new Array();
            keywordData["keyword_recording_id"] = "0";
            keywordData['match_pattern']        = matchPattern;
            keywordData['view_or_record']       = "1";
            keywordData['first_runs_only']      = "1";
            keywordData['network_id']           = "-1";
            keywordData['recording_quality']    = "1";
            keywordData['recordings_per_day']   = "1";
        }

        isKeyword =  (keywordData != null);
        viewOrRecord = keywordData["view_or_record"] == "1";

		title = "'" + keywordData["match_pattern"];
		if(keywordData["avoid_pattern"]){
		    var avoidArray = smartSplit( " ", keywordData["avoid_pattern"], false, '"', false);
		    title += " -" + avoidArray.join(" -");
		}
		title += "'";
           
		description  = "* Use multiple words to search for shows containing ALL the keywords. e.g. surfing boating<br><br>";
		description += "* Use \" around words to search for an exact phrase.  e.g. \"ricky gervais\"<br><br>";
		description += "* Use '-' before words/phrases to exclude them from a search. e.g. surfing boating -golf<br><br>";
		description += "* Use tags to restrict keywords like title, series, episode, desc, actor, director, genre, year, after, before, repeat.<br>";
		description += "  e.g. genre:movie actor:\"angelina Jolie\" before:2006<br>";
                       
        if(keywordData["view_or_record"] == "1")
           	this.setKeywordOptionsMode(0);
		else 
           	this.setKeywordOptionsMode(1);

        this.changeKeywordRecordNetwork(0);
		this.fillEpgSheetDetailsSecondary(updateonly, title, subtitle, year, time, additional, description, isFavorite, recordData, seriesRecordData, isRecommended, partOfSeries, canRecordSingle, isKeyword, viewOrRecord, keywordData, epgData, popularData, recommendedData, favData)
    }
}

function setItemState(item, state) {
    DEBUGLOG("SheetManager.js[2592]: ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state));
    if(item ==  icetv.PILL_RECOMMENDED) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_recommended").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_recommended").style.opacity = 1;
            document.getElementById("epg_sheet_pill_recommended").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_recommended").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_recommended").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_SERIES) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_series").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_series").style.opacity = 1;
            document.getElementById("epg_sheet_pill_series").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_series").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_series").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_SERIES_CANCEL) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_series_cancel").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_series_cancel").style.opacity = 1;
            document.getElementById("epg_sheet_pill_series_cancel").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_series_cancel").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_series_cancel").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_SINGLE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_single").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_single").style.opacity = 1;
            document.getElementById("epg_sheet_pill_single").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_single").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_single").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_KEYWORD_REC) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_keyrec").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_keyrec").style.opacity = 1;
            document.getElementById("epg_sheet_pill_keyrec").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_keyrec").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_keyrec").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_KEYWORD_FAV) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_keyfav").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_keyfav").style.opacity = 1;
            document.getElementById("epg_sheet_pill_keyfav").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_keyfav").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_keyfav").style.display = "inline";
        }
    }

    else if(item ==  icetv.PILL_FAVOURITE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_pill_fav").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_pill_fav").style.opacity = 1;
            document.getElementById("epg_sheet_pill_fav").style.display = "inline";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_pill_fav").style.opacity = 0.5;
            document.getElementById("epg_sheet_pill_fav").style.display = "inline";
        }
    }

    else if(item ==  icetv.BUTTON_ADD_FAV) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_addfav").style.display = "none";
            document.getElementById("sheet_button_addfav").setAttribute("onclick", "");
			document.getElementById("sheet_button_recordonce").style.left = "112px";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_addfav").style.opacity = 1;
            document.getElementById("sheet_button_addfav").style.display = "block";
			document.getElementById("sheet_button_recordonce").style.left = "102px";
            document.getElementById("sheet_button_addfav").setAttribute("onclick", "sht.doAddFav()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_addfav").setAttribute("onclick", "");
            document.getElementById("sheet_button_addfav").style.opacity = 0.5;
            document.getElementById("sheet_button_addfav").style.display = "block";
			document.getElementById("sheet_button_recordonce").style.left = "102px";
        }
    }

    else if(item ==  icetv.BUTTON_DEL_FAV) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_deletefav").style.display = "none";
            document.getElementById("sheet_button_deletefav").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_deletefav").style.opacity = 1;
            document.getElementById("sheet_button_deletefav").style.display = "block";
            document.getElementById("sheet_button_deletefav").setAttribute("onclick", "sht.doRemoveFav()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_deletefav").setAttribute("onclick", "");
            document.getElementById("sheet_button_deletefav").style.opacity = 0.5;
            document.getElementById("sheet_button_deletefav").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_CREATE_KEYWORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_createkeyword").style.display = "none";
            document.getElementById("sheet_button_createkeyword").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_createkeyword").style.opacity = 1;
            document.getElementById("sheet_button_createkeyword").style.display = "block";
            document.getElementById("sheet_button_createkeyword").setAttribute("onclick", "sht.showCreateKeywordOptions()");
			document.getElementById("sheet_button_recordonce").style.left = "95px";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_createkeyword").setAttribute("onclick", "");
            document.getElementById("sheet_button_createkeyword").style.opacity = 0.5;
            document.getElementById("sheet_button_createkeyword").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_RECORD_KEYWORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_recordkeyword").style.display = "none";
            document.getElementById("sheet_button_recordkeyword").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_recordkeyword").style.opacity = 1;
            document.getElementById("sheet_button_recordkeyword").style.display = "block";
            document.getElementById("sheet_button_recordkeyword").setAttribute("onclick", "sht.showRecordKeywordOptions()");
			document.getElementById("sheet_button_recordonce").style.left = "95px";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_recordkeyword").setAttribute("onclick", "");
            document.getElementById("sheet_button_recordkeyword").style.opacity = 0.5;
            document.getElementById("sheet_button_recordkeyword").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_UPDATE_KEYWORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_updatekeyword").style.display = "none";
            document.getElementById("sheet_button_updatekeyword").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_updatekeyword").style.opacity = 1;
            document.getElementById("sheet_button_updatekeyword").style.display = "block";
            document.getElementById("sheet_button_updatekeyword").setAttribute("onclick", "sht.showUpdateKeywordOptions()");
			document.getElementById("sheet_button_recordonce").style.left = "95px";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_updatekeyword").setAttribute("onclick", "");
            document.getElementById("sheet_button_updatekeyword").style.opacity = 0.5;
            document.getElementById("sheet_button_updatekeyword").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_DELETE_KEYWORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_deletekeyword").style.display = "none";
            document.getElementById("sheet_button_deletekeyword").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_deletekeyword").style.opacity = 1;
            document.getElementById("sheet_button_deletekeyword").style.display = "block";
            document.getElementById("sheet_button_deletekeyword").setAttribute("onclick", "sht.doRemoveKeyword()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_deletekeyword").setAttribute("onclick", "");
            document.getElementById("sheet_button_deletekeyword").style.opacity = 0.5;
            document.getElementById("sheet_button_deletekeyword").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_RECORD_SERIES) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_recordseries").style.display = "none";
            document.getElementById("sheet_button_recordseries").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_recordseries").style.opacity = 1;
            document.getElementById("sheet_button_recordseries").style.display = "block";
            document.getElementById("sheet_button_recordseries").setAttribute("onclick", "sht.showRecordSeriesOptions()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_recordseries").setAttribute("onclick", "");
            document.getElementById("sheet_button_recordseries").style.opacity = 0.5;
            document.getElementById("sheet_button_recordseries").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_UPDATE_SERIES) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_updateseries").style.display = "none";
            document.getElementById("sheet_button_updateseries").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_updateseries").style.opacity = 1;
            document.getElementById("sheet_button_updateseries").style.display = "block";
            document.getElementById("sheet_button_updateseries").setAttribute("onclick", "sht.showUpdateSeriesOptions()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_updateseries").setAttribute("onclick", "");
            document.getElementById("sheet_button_updateseries").style.opacity = 0.5;
            document.getElementById("sheet_button_updateseries").style.display = "block";
        }
    }

    else if(item ==  icetv.BUTTON_RECORD_ONCE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet_button_recordonce").style.display = "none";
            document.getElementById("sheet_button_recordonce").setAttribute("onclick", "");
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet_button_recordonce").style.opacity = 1;
            document.getElementById("sheet_button_recordonce").style.display = "block";
            document.getElementById("sheet_button_recordonce").setAttribute("onclick", "sht.showRecordOnceOptions()");
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet_button_recordonce").setAttribute("onclick", "");
            document.getElementById("sheet_button_recordonce").style.opacity = 0.5;
            document.getElementById("sheet_button_recordonce").style.display = "block";
        }
    }

    else if(item == icetv.OPTION_SHEET_SINGLE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-single-record-options").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-single-record-options").style.opacity = 1;
            document.getElementById("epg-sheet-single-record-options").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-single-record-options").style.opacity = 0.5;
            document.getElementById("epg-sheet-single-record-options").style.display = "block";
        }
    }

    else if(item == icetv.OPTION_SHEET_SERIES) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-series-record-options").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-series-record-options").style.opacity = 1;
            document.getElementById("epg-sheet-series-record-options").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-series-record-options").style.opacity = 0.5;
            document.getElementById("epg-sheet-series-record-options").style.display = "block";
        }
    }

    else if(item == icetv.OPTION_SHEET_KEYWORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-keyword-record-options").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-keyword-record-options").style.opacity = 1;
            document.getElementById("epg-sheet-keyword-record-options").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-keyword-record-options").style.opacity = 0.5;
            document.getElementById("epg-sheet-keyword-record-options").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_TITLE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-show-name").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-show-name").style.opacity = 1;
            document.getElementById("epg-sheet-show-name").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-show-name").style.opacity = 0.5;
            document.getElementById("epg-sheet-show-name").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_SUBTITLE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-show-episode").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-show-episode").style.opacity = 1;
            document.getElementById("epg-sheet-show-episode").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-show-episode").style.opacity = 0.5;
            document.getElementById("epg-sheet-show-episode").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_TIME) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-show-time").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-show-time").style.opacity = 1;
            document.getElementById("epg-sheet-show-time").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-show-time").style.opacity = 0.5;
            document.getElementById("epg-sheet-show-time").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_DESCRIPTION) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-show-description").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-show-description").style.opacity = 1;
            document.getElementById("epg-sheet-show-description").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-show-description").style.opacity = 0.5;
            document.getElementById("epg-sheet-show-description").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_ADDITIONAL) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-show-additional").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-show-additional").style.opacity = 1;
            document.getElementById("epg-sheet-show-additional").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-show-additional").style.opacity = 0.5;
            document.getElementById("epg-sheet-show-additional").style.display = "block";
        }
    }

    else if(item == icetv.SHOW_DELETE_BUTTONS) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-record-locations").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-record-locations").style.opacity = 1;
            document.getElementById("epg-sheet-record-locations").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-record-locations").style.opacity = 0.5;
            document.getElementById("epg-sheet-record-locations").style.display = "block";
        }
    }

    else if(item == icetv.SHEET_BUTTONS) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-buttons").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-buttons").style.opacity = 1;
            document.getElementById("epg-sheet-buttons").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-buttons").style.opacity = 0.5;
            document.getElementById("epg-sheet-buttons").style.display = "block";
        }
    }

    else if(item == icetv.SHEET_REC_BUTTONS) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-rec-delete-buttons").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-rec-delete-buttons").style.opacity = 1;
            document.getElementById("sheet-rec-delete-buttons").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-rec-delete-buttons").style.opacity = 0.5;
            document.getElementById("sheet-rec-delete-buttons").style.display = "block";
        }
    }

    else if(item == icetv.SHEET_REC_DIVIDERS) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-rec-controls-divider").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-rec-controls-divider").style.opacity = 1;
            document.getElementById("sheet-rec-controls-divider").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-rec-controls-divider").style.opacity = 0.5;
            document.getElementById("sheet-rec-controls-divider").style.display = "block";
        }
    }

    else if(item == icetv.EPG_SHEET) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet").style.opacity = 1;
            document.getElementById("epg-sheet").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet").style.opacity = 0.5;
            document.getElementById("epg-sheet").style.display = "block";
        }
    }

    else if(item == icetv.SHEET_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-container").style.opacity = 1;
            document.getElementById("sheet-container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-container").style.opacity = 0.5;
            document.getElementById("sheet-container").style.display = "block";
        }
    }

    else if(item == icetv.EPG_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_container").style.opacity = 1;
            document.getElementById("epg_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_container").style.opacity = 0.5;
            document.getElementById("epg_container").style.display = "block";
        }
    }
    else if(item == icetv.POPULAR_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("popular_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("popular_container").style.opacity = 1;
            document.getElementById("popular_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("popular_container").style.opacity = 0.5;
            document.getElementById("popular_container").style.display = "block";
        }
    }
    else if(item == icetv.UPCOMING_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("myguideupcoming_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("myguideupcoming_container").style.opacity = 1;
            document.getElementById("myguideupcoming_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("myguideupcoming_container").style.opacity = 0.5;
            document.getElementById("myguideupcoming_container").style.display = "block";
        }
    }
    else if(item == icetv.SERIES_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("myguideseries_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("myguideseries_container").style.opacity = 1;
            document.getElementById("myguideseries_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("myguideseries_container").style.opacity = 0.5;
            document.getElementById("myguideseries_container").style.display = "block";
        }
    }
    else if(item == icetv.RECOMMENDED_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("recommended_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("recommended_container").style.opacity = 1;
            document.getElementById("recommended_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("recommended_container").style.opacity = 0.5;
            document.getElementById("recommended_container").style.display = "block";
        }
    }
    else if(item == icetv.RECOMMENDED_CONTAINER) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("recommended_container").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("recommended_container").style.opacity = 1;
            document.getElementById("recommended_container").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("recommended_container").style.opacity = 0.5;
            document.getElementById("recommended_container").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_SINGLE_RECORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-record-single-button-record").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-record-single-button-record").style.opacity = 1;
            document.getElementById("sheet-record-single-button-record").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-record-single-button-record").style.opacity = 0.5;
            document.getElementById("sheet-record-single-button-record").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_SINGLE_CANCEL) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_single_record_cancel").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_single_record_cancel").style.opacity = 1;
            document.getElementById("epg_sheet_single_record_cancel").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_single_record_cancel").style.opacity = 0.5;
            document.getElementById("epg_sheet_single_record_cancel").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_SERIES_RECORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-record-series-button-record").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-record-series-button-record").style.opacity = 1;
            document.getElementById("sheet-record-series-button-record").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-record-series-button-record").style.opacity = 0.5;
            document.getElementById("sheet-record-series-button-record").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_SERIES_UPDATE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-update-series-button-update").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-update-series-button-update").style.opacity = 1;
            document.getElementById("sheet-update-series-button-update").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-update-series-button-update").style.opacity = 0.5;
            document.getElementById("sheet-update-series-button-update").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_SERIES_CANCEL) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_series_record_cancel").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_series_record_cancel").style.opacity = 1;
            document.getElementById("epg_sheet_series_record_cancel").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_series_record_cancel").style.opacity = 0.5;
            document.getElementById("epg_sheet_series_record_cancel").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_KEYWORD_RECORD) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-record-keyword-button-create").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-record-keyword-button-create").style.opacity = 1;
            document.getElementById("sheet-record-keyword-button-create").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-record-keyword-button-create").style.opacity = 0.5;
            document.getElementById("sheet-record-keyword-button-create").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_KEYWORD_UPDATE) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("sheet-record-keyword-button-update").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("sheet-record-keyword-button-update").style.opacity = 1;
            document.getElementById("sheet-record-keyword-button-update").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("sheet-record-keyword-button-update").style.opacity = 0.5;
            document.getElementById("sheet-record-keyword-button-update").style.display = "block";
        }
    }
    else if(item == icetv.BUTTON_KEYWORD_CANCEL) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg_sheet_keyword_record_cancel").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg_sheet_keyword_record_cancel").style.opacity = 1;
            document.getElementById("epg_sheet_keyword_record_cancel").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg_sheet_keyword_record_cancel").style.opacity = 0.5;
            document.getElementById("epg_sheet_keyword_record_cancel").style.display = "block";
        }
    }
    else if(item == icetv.IWT_COMMENT) {
        if(state == icetv.STATE_HIDDEN) {
            document.getElementById("epg-sheet-iwt-comment").style.display = "none";
        } else if(state == icetv.STATE_VISIBLE) {
            document.getElementById("epg-sheet-iwt-comment").style.opacity = 1;
            document.getElementById("epg-sheet-iwt-comment").style.display = "block";
        } else if(state == icetv.STATE_DISABLED) {
            document.getElementById("epg-sheet-iwt-comment").style.opacity = 0.5;
            document.getElementById("epg-sheet-iwt-comment").style.display = "block";
        }
    }
}

function addDeleteButton( showIcon, buttonText, line, function_type ) {
    DEBUGLOG("SheetManager.js[2611]: DELETE_SHOW_ICON:: " + showIcon + "    TEXT::'" + buttonText + "'" + "    LINE::" + line + "    FUNCTION_TYPE::" + decodeIceTV(function_type));

    if(showIcon) {
        var deletebutton = document.createElement("div");
        deletebutton.setAttribute("class", "deleterecording");
        if(function_type == icetv.FUNCTION_REMOVE_EPISODE) {
            deletebutton.onClick = function(){ _self.removeEpisodeRecording(); };
            deletebutton.setAttribute("onclick","sht.removeEpisodeRecording()");
        }
        else if(function_type == icetv.FUNCTION_REMOVE_SERIES) {
            deletebutton.onClick = function(){ _self.removeSeriesRecording(); };
            deletebutton.setAttribute("onclick","sht.removeSeriesRecording()");
        }
        else if(function_type == icetv.FUNCTION_REMOVE_KEYWORD) {
            deletebutton.onClick = function(){ _self.removeKeywordRecording(); };
            deletebutton.setAttribute("onclick","sht.removeKeywordRecording()");
        }
        else if(function_type == icetv.FUNCTION_REMOVE_SHOW) {
            deletebutton.onClick = function(){ _self.removeShowRecording(); };
            deletebutton.setAttribute("onclick","sht.removeShowRecording()");
        }
        else if(function_type == icetv.FUNCTION_REMOVE_KEYWORD_EPISODE) {
            deletebutton.onClick = function(){ _self.removeKeywordEpisodeRecording(); };
            deletebutton.setAttribute("onclick","sht.removeKeywordEpisodeRecording()");
        }

        deletebutton.style.top = ((line-1) * 15) + 1 + "px";
        document.getElementById("epg-sheet-record-locations").appendChild(deletebutton);
    }

    var seriesrecordplace = document.createElement("div");
    seriesrecordplace.innerHTML = buttonText;
    seriesrecordplace.style.font = "bold 10px Lucida Grande, Tahoma Bold"
    seriesrecordplace.style.textAlign = "left";
    seriesrecordplace.style.position = "absolute";
    seriesrecordplace.style.left = "16px";
    seriesrecordplace.style.top = ((line-1) * 15) + 1 + "px";
    seriesrecordplace.style.color = "#ffffff";
    seriesrecordplace.style.width = "275px";
    document.getElementById("epg-sheet-record-locations").appendChild(seriesrecordplace);
    
    document.getElementById("epg-sheet-record-locations").style.display = "block";
    document.getElementById("epg-sheet-record-locations").style.height = (line * 15) + "px";
}

function setButtonFunction( button, function_type ) {
    DEBUGLOG("SheetManager.js[3706]: BUTTON:: " + decodeIceTV(button) + "    FUNCTION_TYPE::" + decodeIceTV(function_type));
    if(button == icetv.BUTTON_SINGLE_RECORD) {
        if(function_type == icetv.FUNCTION_RECORD_SHOW) {
            document.getElementById("sheet-record-single-button-record").setAttribute("onclick", "sht.doSingleShowRecord()");
        }
        else if(function_type == icetv.FUNCTION_RECORD_EPISODE) {
            document.getElementById("sheet-record-single-button-record").setAttribute("onclick", "sht.doSingleEpisodeRecord()");
        }
    }
}

function setCommentLinkURL( url ) {
    document.getElementById("epg-sheet-iwt-comment-link").setAttribute("onclick", "widget.openURL('" + url + "')");
}


function clearDeleteButtons() {
    DEBUGLOG("SheetManager.js[2772]:  Clear delete buttons");
	while(document.getElementById("epg-sheet-record-locations").hasChildNodes())
		document.getElementById("epg-sheet-record-locations").removeChild(document.getElementById("epg-sheet-record-locations").firstChild);
}

function setOptionInfoIndex( sheet, item, index  ) {
    DEBUGLOG("SheetManager.js[2615]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    INDEX::" + index);
    if(sheet == option_sheets.SINGLE) {
        DEBUGLOG("SheetManager.js[2905]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    INDEX::" + index + "    UNSUPPORTED");
    }

    else if(sheet == icetv.OPTION_SHEET_SERIES) {
        if(item == icetv.OPTION_DEVICE) {
            sht.changeSeriesRecordDevice(index);
        }
        else if(item == icetv.OPTION_TYPE) {
            sht.changeSeriesRecordType(index);
        }
        else if(item == icetv.OPTION_NETWORK) {
            sht.changeSeriesRecordNetwork(index);
        }
        else if(item == icetv.OPTION_QUALITY) {
            sht.changeSeriesRecordQuality(index);
        }
        else if(item == icetv.OPTION_TIME) {
            sht.changeSeriesRecordTime(index);
        }
        else if(item == icetv.OPTION_LIMIT) {
            sht.changeSeriesRecordLimit(index);
        }
    }

    else if(sheet == icetv.OPTION_SHEET_KEYWORD) {
        if(item == icetv.OPTION_DEVICE) {
            sht.changeKeywordRecordDevice(index);
        }
        else if(item == icetv.OPTION_TYPE) {
            sht.changeKeywordRecordType(index);
        }
        else if(item == icetv.OPTION_NETWORK) {
            sht.changeKeywordRecordNetwork(index);
        }
        else if(item == icetv.OPTION_QUALITY) {
            sht.changeKeywordRecordQuality(index);
        }
        else if(item == icetv.OPTION_TIME) {
            DEBUGLOG("SheetManager.js[2535]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    INDEX::" + index + "    UNSUPPORTED");
        }
        else if(item == icetv.OPTION_LIMIT) {
            sht.changeKeywordRecordLimit(index);
        }
    }
}

function setOptionInfoState( sheet, item, state  ) {
    DEBUGLOG("SheetManager.js[3325]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state));
    if(sheet == option_sheets.SINGLE) {
        DEBUGLOG("SheetManager.js[3327]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
    }

    else if(sheet == icetv.OPTION_SHEET_SERIES) {
        if(item == icetv.OPTION_DEVICE) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-device").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-device").style.display = "block";
                document.getElementById("epg-sheet-series-record-devices").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-devices").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-device").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-device").style.display = "block";
                document.getElementById("epg-sheet-series-record-devices").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_TYPE) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-type").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-type").style.display = "block";
                document.getElementById("epg-sheet-series-record-type-menu").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-type-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-type").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-type").style.display = "block";
                document.getElementById("epg-sheet-series-record-type-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_NETWORK) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-network").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-network").style.display = "block";
                document.getElementById("epg-sheet-series-record-network-menu").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-network-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-network").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-network").style.display = "block";
                document.getElementById("epg-sheet-series-record-network-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_QUALITY) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-quality").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-quality").style.display = "block";
                document.getElementById("epg-sheet-series-record-quality-menu").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-quality-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-quality").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-quality").style.display = "block";
                document.getElementById("epg-sheet-series-record-quality-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_TIME) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-time").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-time").style.display = "block";
                document.getElementById("epg-sheet-series-record-time-menu").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-time-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-time").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-time").style.display = "block";
                document.getElementById("epg-sheet-series-record-time-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_LIMIT) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-series-record-limit").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-limit").style.display = "block";
                document.getElementById("epg-sheet-series-record-limit-menu").style.opacity = 1;
                document.getElementById("epg-sheet-series-record-limit-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-series-record-limit").style.opacity = 0.5;
                document.getElementById("epg-sheet-series-record-limit").style.display = "block";
                document.getElementById("epg-sheet-series-record-limit-menu").style.display = "none";
            }
        }
    }

    else if(sheet == icetv.OPTION_SHEET_KEYWORD) {
        if(item == icetv.OPTION_DEVICE) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-device").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-device").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-devices").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-devices").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-device").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-device").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-devices").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_TYPE) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-type").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-type").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-type-menu").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-type-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-type").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-type").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-type-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_NETWORK) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3333]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-network").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-network").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-network-menu").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-network-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-network").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-network").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-network-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_QUALITY) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-quality").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-quality").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-quality-menu").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-quality-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-quality").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-quality").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-quality-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_TIME) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-time").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-time").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-time-menu").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-time-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-time").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-time").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-time-menu").style.display = "none";
            }
        }
        else if(item == icetv.OPTION_LIMIT) {
            if(state == icetv.STATE_HIDDEN) {
                DEBUGLOG("SheetManager.js[3375]: SHEET:: " + decodeIceTV(sheet) + "    ITEM::" + decodeIceTV(item) + "    STATE::" + decodeIceTV(state) + "    UNSUPPORTED");
            } else if(state == icetv.STATE_VISIBLE) {
                document.getElementById("epg-sheet-keyword-record-limit").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-limit").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-limit-menu").style.opacity = 1;
                document.getElementById("epg-sheet-keyword-record-limit-menu").style.display = "block";
            } else if(state == icetv.STATE_DISABLED) {
                document.getElementById("epg-sheet-keyword-record-limit").style.opacity = 0.5;
                document.getElementById("epg-sheet-keyword-record-limit").style.display = "block";
                document.getElementById("epg-sheet-keyword-record-limit-menu").style.display = "none";
            }
        }
    }
}

function setInputText( item, text  ) {
    DEBUGLOG("SheetManager.js[2544]: INPUT::" + decodeIceTV(item) + "    TEXT::'" + text + "'");
    if(item == icetv.OPTION_KEYWORD_PATTERN) {
        document.getElementById("epg-sheet-keyword-record-pattern").value = text;
    }
}

function setItemText( item, text  ) {
    DEBUGLOG("SheetManager.js[2544]: ITEM::" + decodeIceTV(item) + "    TEXT::'" + text + "'");
    if(item == icetv.SHOW_TITLE) {
        document.getElementById("epg-sheet-show-name").innerHTML = text;
//        document.getElementById("epg-sheet-show-name").setAttribute("class", "ellipsis");
//        document.getElementById("epg-sheet-show-name").style.width = (356 - 12 - 63) + "px"
//        document.getElementById("epg-sheet-show-name").style.width = 100 + "px"
    }
    else if(item == icetv.SHOW_SUBTITLE) {
        document.getElementById("epg-sheet-show-episode").innerHTML = text;
        if(!text || text.length == 0)
            document.getElementById("epg-sheet-show-episode-container").style.display = "none";
        else
            document.getElementById("epg-sheet-show-episode-container").style.display = "block";
    }
    else if(item == icetv.SHOW_TIME) {
        document.getElementById("epg-sheet-show-time").innerHTML = text;
        if(!text || text.length == 0)
            document.getElementById("epg-sheet-show-time-container").style.display = "none";
        else
            document.getElementById("epg-sheet-show-time-container").style.display = "block";
    }
    else if(item == icetv.SHOW_DESCRIPTION) {
        document.getElementById("epg-sheet-show-description").innerHTML = text;
    }
    else if(item == icetv.SHOW_ADDITIONAL) {
        document.getElementById("epg-sheet-show-additional").innerHTML = text;
    }
    else if(item == icetv.SINGLE_RECORD_SHOWTITLE) {
        document.getElementById("epg-sheet-single-record-showtitle").innerHTML = text;
    }
    else if(item == icetv.SERIES_RECORD_SHOWTITLE) {
        document.getElementById("epg-sheet-series-record-showtitle").innerHTML = text;
    }
    else if(item == icetv.KEYWORD_RECORD_SHOWTITLE) {
        document.getElementById("epg-sheet-keyword-record-showtitle").innerHTML = text;
    }

    else if(item == icetv.SINGLE_RECORD_LABEL_TYPE) {
        document.getElementById("epg-sheet-single-record-showtitle").innerHTML = text;
    }
    else if(item == icetv.SERIES_RECORD_LABEL_TYPE) {
        document.getElementById("series_record_label_type").innerHTML = text;
    }
    else if(item == icetv.KEYWORD_RECORD_LABEL_TYPE) {
        document.getElementById("keyword_record_label_type").innerHTML = text;
    }
}

function setItemClass(item, newClass) {
    DEBUGLOG("SheetManager.js[3537]: ITEM::" + decodeIceTV(item) + "    CLASS::" + newClass);
    if(item == icetv.SHEET_SINGLE_CONTAINER) {
        document.getElementById("epg-sheet-single-container").setAttribute("class", newClass);
    }
    else if(item == icetv.SHEET_SERIES_CONTAINER) {
        document.getElementById("epg-sheet-series-container").setAttribute("class", newClass);
    }
    else if(item == icetv.SHEET_KEYWORD_CONTAINER) {
        document.getElementById("epg-sheet-keyword-container").setAttribute("class", newClass);
    }
    else
        DEBUGLOG("SheetManager.js[3537]: ITEM::" + decodeIceTV(item) + "    CLASS::" + newClass + "    UNSUPPORTED");
}

function setItemOpacity(item, opacity) {
    DEBUGLOG("SheetManager.js[2564]: ITEM::" + decodeIceTV(item) + "    OPACITY::" + opacity);
    if(item == icetv.SHOW_TITLE) {
        document.getElementById("epg-sheet-show-name").style.opacity = opacity;
    }
    else if(item == icetv.SHOW_SUBTITLE) {
        document.getElementById("epg-sheet-show-episode").style.opacity = opacity;
    }
    else if(item == icetv.SHOW_TIME) {
        document.getElementById("epg-sheet-show-time").style.opacity = opacity;
    }
    else if(item == icetv.SHOW_DESCRIPTION) {
        document.getElementById("epg-sheet-show-description").style.opacity = opacity;
    }
    else if(item == icetv.SHOW_ADDITIONAL) {
        document.getElementById("epg-sheet-show-additional").style.opacity = opacity;
    }
    else if(item == icetv.SHOW_DELETE_BUTTONS) {
        document.getElementById("epg-sheet-record-locations").style.opacity = opacity;
    }
    else if(item == icetv.SHEET_BUTTONS) {
        document.getElementById("epg-sheet-buttons").style.opacity = opacity;
    }
    else if(item == icetv.SHEET_REC_BUTTONS) {
        document.getElementById("sheet-rec-delete-buttons").style.opacity = opacity;
    }
    else if(item == icetv.SHEET_REC_DIVIDERS) {
        document.getElementById("sheet-rec-controls-divider").style.opacity = opacity;
    }
    else if(item == icetv.EPG_SHEET) {
        document.getElementById("epg-sheet").style.opacity = opacity;
    }
    else if(item == icetv.SHEET_CONTAINER) {
        document.getElementById("sheet-container").style.opacity = opacity;
    }
    else if(item == icetv.EPG_CONTAINER) {
        document.getElementById("epg_container").style.opacity = opacity;
    }
    else if(item == icetv.POPULAR_CONTAINER) {
        document.getElementById("popular_container").style.opacity = opacity;
    }
    else if(item == icetv.UPCOMING_CONTAINER) {
        document.getElementById("myguideupcoming_container").style.opacity = opacity;
    }
    else if(item == icetv.SERIES_CONTAINER) {
        document.getElementById("myguideseries_container").style.opacity = opacity;
    }
    else if(item == icetv.RECOMMENDED_CONTAINER) {
        document.getElementById("recommended_container").style.opacity = opacity;
    }
}


function forceCloseSheets() {
    sht.forceCloseSheets();
}

function prepareSheetForDisplay() {
	var sheetTopHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-top"),"").getPropertyValue("height"), 10);
	var sheetButtonsHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-buttons"),"").getPropertyValue("height"), 10);
	var sheetBottomHeight = parseInt(document.defaultView.getComputedStyle(document.getElementById("epg-sheet-bottom"),"").getPropertyValue("height"), 10);

//    DEBUGLOG("SheetManager.js[4266]: sheetTopHeight: " + sheetTopHeight);
//    DEBUGLOG("SheetManager.js[4267]: sheetButtonsHeight: " + sheetButtonsHeight);
//    DEBUGLOG("SheetManager.js[4268]: sheetBottomHeight: " + sheetBottomHeight);
	
	sheetHeight = sheetTopHeight + sheetButtonsHeight + sheetBottomHeight
	document.getElementById("epg-sheet-buttons").style.top = sheetTopHeight + "px"
	document.getElementById("epg-sheet-bottom").style.top = (sheetTopHeight + sheetButtonsHeight) + "px"
	
	document.getElementById("sheet-container").style.height = sheetHeight + "px"
	document.getElementById("epg-sheet").style.top = -sheetHeight + "px"
	document.getElementById("epg-sheet").style.opacity = 1;

	resizeFront(sheetHeight + 72);
}

function setDeviceForSheetByLabel( sheet, device_label ) {
    DEBUGLOG("SheetManager.js[3318]: setDeviceForSheetByLabel: SHEET::" + decodeIceTV(sheet) + "    DEVICE_LABEL::" + device_label);
    var deviceID = dv.indexForName(device_label);
    var foundDevice = false;

    if(sheet == icetv.OPTION_SHEET_SINGLE) {
        for(var i=0;i<document.getElementById("epg-sheet-single-record-devices").options.length;i++){
            if(document.getElementById("epg-sheet-single-record-devices").options[i].value == deviceID){
                foundDevice = true;
                sht.changeSingleRecordDeviceFromMenu(i);
                break;
            }
        }
        if(!foundDevice){
            if(document.getElementById("epg-sheet-single-record-devices").options.length > 0)
                sht.changeSingleRecordDeviceFromMenu(0);
        }
    }
    else if(sheet == icetv.OPTION_SHEET_SERIES) {
        for(var i=0;i<document.getElementById("epg-sheet-series-record-devices").options.length;i++){
            if(document.getElementById("epg-sheet-series-record-devices").options[i].value == deviceID){
                foundDevice = true;
                sht.changeSeriesRecordDevice(i);
                break;
            }
        }
        if(!foundDevice){
            if(document.getElementById("epg-sheet-series-record-devices").options.length > 0)
                sht.changeSeriesRecordDevice(0);
        }
    }
    else if(sheet == icetv.OPTION_SHEET_KEYWORD) {
        for(var i=0;i<document.getElementById("epg-sheet-keyword-record-devices").options.length;i++){
            if(document.getElementById("epg-sheet-keyword-record-devices").options[i].value == deviceID){
                foundDevice = true;
                sht.changeKeywordRecordDevice(i);
                break;
            }
        }
        if(!foundDevice){
            if(document.getElementById("epg-sheet-single-record-devices").options.length > 0)
                sht.changeKeywordRecordDevice(0);
        }
    }
}

function timeIndexForMins(time){
	for(x=0;x<document.getElementById("epg-sheet-series-record-time-menu").options.length;x++){
		if(document.getElementById("epg-sheet-series-record-time-menu").options[x].value == time)
			return x;
	}
	return -1;
}
